function [ECOTRAN] = ECOTRANuncertainty_05062016(EwEResult, MonteCarloStore)
% convert EwE results into a bottom-up (donor-driven), bioenergetic budget (= consumption budget)
% by Jim Ruzicka
% takes:
%       EwEResult       = the base EwE model as prepared by f_AggregateResults_EwE_08092013.m
%       MonteCarloStore = retained Monte Carlo models
% calls:
%       f_ECOfunction_05142015                      returns a single ECOTRAN model for 1 "type" EwE model or 1 MonteCarlo EwE model
%               f_RedistributeCannibalism           remove cannibalism terms on diagonal of matrix EwE_diet
%               f_CalcPredationMatrix               for each producer, p, and consumer, c: ((b_pc * Q_c) / M2_p)) = the fraction of total predation on each producer, p, going to each consumer, c
% returns:
%   ECOTRAN.EnergyBudget_matrix
%       producer groups (p) run across columns
%       rows:
%           metabolism term (2 rows, pelagic & benthic excretion)
%           predation by individual predators (n rows)
%           fisheries (n rows)
%           terminal pelagic detritus (1 row)
%           terminal benthic detritus (1 row)
%           BA = biomass accumulation (1 row)
%           EM = emigration (1 row) (immigration is negative)
%       NOTE: each column sums to 1 except for difference due to BA & EM (fishery clms do not sum to 1; landings are removed from system as EM); Terminal Benthic Detritus column sums to 1 BUT does NOT include OtherMortality nor EM
%       NOTE: BA & EM are handled in BioenergeticBudget_ProductionDetail, NOT in EnergyBudget_matrix
%   ECOTRAN.BioenergeticBudget (sum of each clm = 1, except for fisheries)
%           row 1 = BioenergeticBudget_production
%           row 2 = BioenergeticBudget_feces
%           row 3 = BioenergeticBudget_metabolism
%   ECOTRAN.BioenergeticBudget_ProductionDetail (sum of each clm = ECOTRAN.BioenergeticBudget_production
%           row 1 = BioenergeticBudget_SumPredation (total consumption of each group p going to all its consumers)
%           row 2 = BioenergeticBudget_eggs (total consumption of each group p going to eggs, gametes, or live births)
%           row 3 = BioenergeticBudget_OtherMortality (total consumption of each group p going to 
%           row 4 = BioenergeticBudget_BA (total consumption of each group p going to biomass accumulation)
%           row 5 = BioenergeticBudget_EM (total consumption of each group p going to emigration)
%   ECOTRAN.BioenergeticBudget_OtherMortDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
%   ECOTRAN.BioenergeticBudget_FecesDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
%   ECOTRAN.ProductionBudget (each clm sums to 1; negative values are allowed)
%           row 1 = ProductionBudget_predation (total production of each group p going to the sum of all predation pressure on each group p)
%           row 2 = ProductionBudget_eggs (total production of each group p going to eggs, gametes, or live births)
%           row 3 = ProductionBudget_OtherMortality
%           row 4 = ProductionBudget_BA
%           row 5 = ProductionBudget_EM
%   ECOTRAN.ProductionBudget_OtherMortDetail
%           row 1 = flow to terminal pelagic detritus
%           row 2 = flow to terminal benthic detritus
% revision date: 5-4-2016
%       (corrected eggs in detritus address search error in step 1d: 5-6-2016 JR)


% *************************************************************************
% STEP 1: prepare EwEResults-----------------------------------------------
% step 1a: direct feces and senescence mortality to either pelagic or benthic detritus by fractional value
DetritusFate_feces        = EwEResult.DetritusFate_feces'; % row 1 = pelagic detritus; row 2 = benthic detritus; (2 horizontal vectors)
DetritusFate_senescence   = EwEResult.DetritusFate_senescence'; % row 1 = pelagic detritus; row 2 = benthic detritus; (2 horizontal vectors)
PelagicBacterialReduction = EwEResult.PelagicBacterialReduction; % fraction of pelagic detritus returned to DIN (scaler)
BenthicBacterialReduction = EwEResult.BenthicBacterialReduction; % fraction of benthic detritus returned to DIN (assumed no direct return to surface mixed layer) (scaler)
EwE_DetritusFate          = EwEResult.EwE_DetritusFate'; % EwE detritus fate (NOT the ECOTRAN parameters); note transpose to stack of horizontal vectors

% step 1b: direct nutrient uptake and recycling
ExcretionFate             = EwEResult.ExcretionFate'; % row 1 = surface mixed layer; row 2 = sub-surface; (2 horizontal vectors)
PhytoUptake_NO3           = EwEResult.PhytoUptake_NO3; % row 1 = fraction of NO3 to small phytoplankton; row 2 = fraction of NO3 to large phytoplankton; (vertical vector); or set to = EwEResult.PhytoUptake_NO3(1:EwEResult.num_PrimaryProducers) to trim extra cells if necessary
PhytoUptake_NH4           = EwEResult.PhytoUptake_NH4; % row 1 = fraction of NH4 to small phytoplankton; row 2 = fraction of NH4 to large phytoplankton; (vertical vector); or set to = EwEResult.PhytoUptake_NH4(1:EwEResult.num_PrimaryProducers) to trim extra cells if necessary
Oxidation_NH4             = EwEResult.Oxidation_NH4; % fraction of NH4 produced oxidized directly back to NO3 abiologically; this should take precedence over phytoplankton uptake of NH4 in code below; (vertical vector)

% step 1c: misc
GroupType                 = EwEResult.GroupType;
GroupType_nutrients       = EwEResult.GroupType_nutrients;
AggLabel                  = EwEResult.AggLabel;
AggLabel_nutrients        = EwEResult.AggLabel_nutrients;
FullResNums_EwE           = EwEResult.FullResNums;
ProductionLossScaler      = EwEResult.ProductionLossScaler';
RetentionScaler           = EwEResult.RetentionScaler';
FunctionalResponseParams  = EwEResult.FunctionalResponseParams';

% step 1d: row addresses of specific group types
looky_PrimaryProducers    = find(floor(GroupType) == EwEResult.GroupTypeDef_ANYPrimaryProd); %  primary producer groups
looky_eggs                = find(GroupType == EwEResult.GroupTypeDef_eggs);
looky_detritus            = find(floor(GroupType) == EwEResult.GroupTypeDef_ANYDetritus); %  detritus groups
looky_PelagicDetritus     = find(GroupType == EwEResult.GroupTypeDef_terminalPlgcDetr); % terminal pelagic detritus group(s) in EwE
looky_BenthicDetritus     = find(GroupType == EwEResult.GroupTypeDef_terminalBnthDetr); % terminal benthic detritus group(s) in EwE
looky_EggsAndDetritus     = [looky_eggs; looky_detritus];
looky_EggsAndDetritus     = sort(looky_EggsAndDetritus); % error correction JR 5-6-2015
looky_fisheries           = find(floor(GroupType) == EwEResult.GroupTypeDef_fishery); %  fisheries groups
looky_consumers           = find(floor(GroupType) == EwEResult.GroupTypeDef_ANYConsumer & GroupType ~= EwEResult.GroupTypeDef_eggs); %  consumer groups (excludes eggs)
looky_plgcBacteria        = find(GroupType == EwEResult.GroupTypeDef_plgcBacteria);
looky_bnthBacteria        = find(GroupType == EwEResult.GroupTypeDef_bnthBacteria);

% step 1e: numbers of specific group types
num_NitrogenNutrients     = EwEResult.num_NitrogenNutrients;
num_PrimaryProducers      = EwEResult.num_PrimaryProducers;
num_eggs                  = EwEResult.num_eggs;
num_detritus              = EwEResult.num_detritus;
num_PelagicDetritus       = length(looky_PelagicDetritus);
num_BenthicDetritus       = length(looky_BenthicDetritus);
num_EggsAndDetritus       = EwEResult.num_EggsAndDetritus;
num_consumers             = length(looky_consumers);
num_fisheries             = EwEResult.num_fisheries;
num_bacteria              = length(looky_plgcBacteria) + length(looky_bnthBacteria);
num_ECOTRAN_groups        = num_NitrogenNutrients + num_PrimaryProducers + num_consumers + num_EggsAndDetritus + num_fisheries + num_bacteria; % (QQQ num_EggsAndDetritus is not right one to use in case of weird number of terminal detr)
num_EwE_groups            = num_PrimaryProducers + num_consumers + num_EggsAndDetritus + num_bacteria; % does not include fisheries

GroupType_EggsAndDetritus = GroupType(looky_EggsAndDetritus);
looky_OffalInDetritus     = find(GroupType_EggsAndDetritus == EwEResult.GroupTypeDef_offal);
looky_PlgcDetrInDetritus  = find(GroupType_EggsAndDetritus == EwEResult.GroupTypeDef_terminalPlgcDetr);
looky_BnthcDetrInDetritus = find(GroupType_EggsAndDetritus == EwEResult.GroupTypeDef_terminalBnthDetr);
looky_EggsInDetritus      = find(GroupType_EggsAndDetritus == EwEResult.GroupTypeDef_eggs);
looky_DetrInDetritus      = find(floor(GroupType_EggsAndDetritus) == EwEResult.GroupTypeDef_ANYDetritus);
AggLabel_EggsAndDetritus  = EwEResult.AggLabel(looky_EggsAndDetritus);

% step 1f: fisheries info
DetritusFate_feces_fisheries       = EwEResult.DetritusFate_feces_fisheries';
DetritusFate_senescence_fisheries  = EwEResult.DetritusFate_senescence_fisheries';
ExcretionFate_fisheries            = EwEResult.ExcretionFate_fisheries';
ProductionLossScaler_fisheries     = EwEResult.ProductionLossScaler_fisheries';
RetentionScaler_fisheries          = EwEResult.RetentionScaler_fisheries';
FunctionalResponseParams_fisheries = EwEResult.FunctionalResponseParams_fisheries';
AggLabel_fisheries                 = EwEResult.AggLabel_fisheries;

% step 1g: append fishery info
DetritusFate_feces(1:2, (end+1):(end+num_fisheries))       = DetritusFate_feces_fisheries; % fishery offal = fishery feces; all to benthic detritus
DetritusFate_senescence(1:2, (end+1):(end+num_fisheries))  = DetritusFate_senescence_fisheries; % no senile fisheries
ExcretionFate(1:2, (end+1):(end+num_fisheries))            = ExcretionFate_fisheries; % no fishery metabolism
ProductionLossScaler(1, (end+1):(end+num_fisheries))       = ProductionLossScaler_fisheries;
RetentionScaler(1, (end+1):(end+num_fisheries))            = RetentionScaler_fisheries;
FunctionalResponseParams(1:4, (end+1):(end+num_fisheries)) = FunctionalResponseParams_fisheries;
AggLabel((end+1):(end+num_fisheries))                      = AggLabel_fisheries; % append 'fishery' to AggLabel





% *************************************************************************
% STEP 2: prep MonteCarloStore structure variable from .mat----------------
% step 2a: either prep MonteCarloStore or use only the 1 EwEResult base model
if ~isempty(MonteCarloStore)
    
    % QQQ temp patch for MonteCarloStore EE & fisheries info---------------
    % (in future, have all these retained when saving each MonteCarlo model)
    MonteCarloStore.EwE_EE            = MonteCarloStore.EcotrophicEfficiency; % (2D matrix: groups X MonteCarlo_layers)
    
    % MonteCarloStore.Landings (3D matrix: groups X gear_type X MonteCarlo layers)
    total_landings                    = sum(MonteCarloStore.Landings, 1); % total landings for each gear type (1 X gear_type X MonteCarlo layers)
    total_discards                    = sum(MonteCarloStore.Discards, 1); % total discards for each gear type (1 X gear_type X MonteCarlo layers)
    total_landings                    = squeeze(total_landings); % (2D matrix: gear_type X MonteCarlo_layers)
    total_discards                    = squeeze(total_discards);
    [temp_rows, temp_layers]          = size(total_landings);
    if temp_layers == 1 % transpose MonteCarlo layers to run across clms (in cases when there is only 1 gear type, squeeze result needs a transpose)
        total_landings                = total_landings';
        total_discards                = total_discards';
        [temp_rows, temp_layers]      = size(total_landings);
    end
    total_fisheries                   = total_landings + total_discards; % (2D matrix: gear_type X MonteCarlo_layers)
    
    MonteCarloStore.Biomass_fisheries = total_fisheries; % (2D matrix: gear_type X MonteCarlo_layers)
    MonteCarloStore.PB_fisheries      = total_landings ./ total_fisheries; % (2D matrix; gear X MonteCarlo layers)
    MonteCarloStore.PB_fisheries(isnan(MonteCarloStore.PB_fisheries)) = 0; % filter out div/0 NaN errors (this should be very rare unless there is a gear-type with 0 landings and 0 discards); (2D matrix; gear X MonteCarlo layers)
    MonteCarloStore.QB_fisheries      = ones(num_fisheries, temp_layers);  % QB on fisheries are all 1
    MonteCarloStore.PQ_fisheries      = MonteCarloStore.PB_fisheries;
    MonteCarloStore.AE_fisheries      = MonteCarloStore.PB_fisheries;
    MonteCarloStore.BA_fisheries      = zeros(num_fisheries, temp_layers); % BA on fisheries are all 0
    MonteCarloStore.EM_fisheries      = zeros(num_fisheries, temp_layers); % EM on fisheries are all 0 (QQQ need to fix in future)
    MonteCarloStore.EwE_EE_fisheries  = zeros(num_fisheries, temp_layers); % EE on fisheries are all 0
    
%     MonteCarloStore.Landings          = reshape(MonteCarloStore.Landings, num_fisheries, num_EwE_groups, temp_layers); % note transpose (matrix: gear X group X MonteCarlo layers) QQQ ERROR HERE!!!???
%     MonteCarloStore.Discards          = reshape(MonteCarloStore.Discards, num_fisheries, num_EwE_groups, temp_layers); % note transpose (matrix: gear X group X MonteCarlo layers)
    
    % ---------------------------------------------------------------------
    
elseif isempty(MonteCarloStore)
    
    MonteCarloStore.Biomass           = EwEResult.Biomass;
    MonteCarloStore.PB                = EwEResult.PB;
    MonteCarloStore.QB                = EwEResult.QB;
    MonteCarloStore.PQ                = EwEResult.PQ;
    MonteCarloStore.AE                = EwEResult.AE;
    MonteCarloStore.BA                = EwEResult.BA;
    MonteCarloStore.EM                = EwEResult.EM;    
    MonteCarloStore.EwE_EE            = EwEResult.EwE_EE;
    MonteCarloStore.diet              = EwEResult.Diet;
    MonteCarloStore.Consumption       = EwEResult.Consumption;
%     MonteCarloStore.Landings          = EwEResult.Landings'; % QQQ error transpose???; note transpose (matrix: gear X group)
%     MonteCarloStore.Discards          = EwEResult.Discards'; % note transpose (matrix: gear X group)
    MonteCarloStore.Landings          = EwEResult.Landings; % (2D matrix: group X gear)
    MonteCarloStore.Discards          = EwEResult.Discards; % (2D matrix: group X gear)    
   
    MonteCarloStore.Biomass_fisheries = EwEResult.Biomass_fisheries; % (vector) 
    MonteCarloStore.PB_fisheries      = EwEResult.PB_fisheries; % (vector)
    MonteCarloStore.QB_fisheries      = EwEResult.QB_fisheries; % (vector)
    MonteCarloStore.PQ_fisheries      = EwEResult.PQ_fisheries; % (vector)
    MonteCarloStore.AE_fisheries      = EwEResult.AE_fisheries; % (vector)
    MonteCarloStore.BA_fisheries      = EwEResult.BA_fisheries; % (vector)
    MonteCarloStore.EM_fisheries      = EwEResult.EM_fisheries; % (vector)  
    MonteCarloStore.EwE_EE_fisheries  = EwEResult.EwE_EE_fisheries; % (vector)

end

% step 2b: get the size of the model set to work with
[MonteCarlo_rows, MonteCarlo_layers]             = size(MonteCarloStore.PB);
[MonteCarloDiet_rows, MonteCarloDiet_clms, toss] = size(MonteCarloStore.diet); % has header row & clm, has import diet row

% step 2c: prep MonteCarloStore: parameters from EwE (physiology, EE); (MATRIX of vertical vectors)
EwE_Biomass                = MonteCarloStore.Biomass; % (t/km2); (2D matrix: groups X trials); NOTE: groups does not yet include fisheries
EwE_PB                     = MonteCarloStore.PB; % (1/y); (matrix: groups X trials)
EwE_QB                     = MonteCarloStore.QB; % (1/y); (matrix: groups X trials)
EwE_PQ                     = MonteCarloStore.PQ; % (unitless fraction, 0 to 1); (matrix: groups X trials)
EwE_AE                     = MonteCarloStore.AE; % defined assimilation efficiency of each group, j; % (unitless fraction, 0 to 1); (matrix: groups X trials)
EwE_BA                     = MonteCarloStore.BA; % biomass accumulation rate of each group, j; (t/km2/y); (vertical vector)
EwE_EM                     = MonteCarloStore.EM; % gross emigration, immigration, physical loss rate of each group, j; (t/km2/y); (vertical vector); (this is defined as fraction of production)
EwE_EE                     = MonteCarloStore.EwE_EE; % (unitless fraction, 0 to 1); (matrix: groups X trials)
working_diet               = MonteCarloStore.diet(2:end, 2:end, 1:MonteCarlo_layers); % remove prey & predator group code headers; NOTE that this diet vector DOES include the import diet row
working_consumption        = MonteCarloStore.Consumption; % (matrix)
working_consumption(isnan(working_consumption)) = 0; % QQQ 1/11/15; convert NaNs to 0 (phyto & detritus grps)
% EwE_Landings               = MonteCarloStore.Landings; % QQQ changed comments on error below --- landings w/o discard; (t/km2/y); (3D matrix: gear X group X MonteCarlo_trials)
% EwE_Discards               = MonteCarloStore.Discards; % (t/km2/y); (3D matrix: gear X group X MonteCarlo_trials)
% EwE_TotalFishery           = EwE_Landings + EwE_Discards; % landings and discards; (t/km2/y); (3D matrix: gear X group X MonteCarlo_trials)
EwE_Landings               = MonteCarloStore.Landings; % landings w/o discard; (t/km2/y); (3D matrix: groups X gear X MonteCarlo_trials)
EwE_Discards               = MonteCarloStore.Discards; % (t/km2/y); (3D matrix: groups X gear X MonteCarlo_trials)
EwE_TotalFishery           = EwE_Landings + EwE_Discards; % landings + discards; (t/km2/y); (3D matrix: groups X gear X MonteCarlo_trials)

EwE_Biomass_fisheries      = MonteCarloStore.Biomass_fisheries; % (t/km2); (2D matrix: num_gear X MonteCarlo_trials)
EwE_PB_fisheries           = MonteCarloStore.PB_fisheries; % (1/y)
EwE_QB_fisheries           = MonteCarloStore.QB_fisheries; % (1/y)
EwE_PQ_fisheries           = MonteCarloStore.PQ_fisheries; % (unitless fraction, 0 to 1)
EwE_AE_fisheries           = MonteCarloStore.AE_fisheries; % defined assimilation efficiency of each group, j; % (unitless fraction, 0 to 1); (vertical vector)
EwE_BA_fisheries           = MonteCarloStore.BA_fisheries; % biomass accumulation rate of each group, j; (t/km2/y); (vertical vector)
EwE_EM_fisheries           = MonteCarloStore.EM_fisheries; % gross emigration, immigration, physical loss rate of each group, j; (t/km2/y); (vertical vector); (this is defined as fraction of production)
EwE_EE_fisheries           = MonteCarloStore.EwE_EE_fisheries; % (unitless fraction, 0 to 1)

% step 2d: append fisheries (landings + discards)
EwE_Biomass((end+1):(end+num_fisheries), 1:MonteCarlo_layers) = EwE_Biomass_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_PB((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_PB_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_QB((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_QB_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_PQ((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_PQ_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_AE((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_AE_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_BA((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_BA_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_EM((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_EM_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)
EwE_EE((end+1):(end+num_fisheries), 1:MonteCarlo_layers)      = EwE_EE_fisheries; % append fisheries as rows; (2D matrix: (groups + num_gear) X MonteCarlo_trials)





% *************************************************************************
% STEP 3: compile ModelDefinitions-----------------------------------------
ModelDefinitions.DetritusFate_feces              = DetritusFate_feces;
ModelDefinitions.DetritusFate_senescence         = DetritusFate_senescence; % row 1 = pelagic detritus; row 2 = benthic detritus; (2 horizontal vectors)
ModelDefinitions.PelagicBacterialReduction       = PelagicBacterialReduction; % fraction of pelagic detritus returned to DIN (scaler)
ModelDefinitions.BenthicBacterialReduction       = BenthicBacterialReduction; % fraction of benthic detritus returned to DIN (assumed no direct return to surface mixed layer) (scaler)
ModelDefinitions.EwE_DetritusFate                = EwE_DetritusFate; % EwE detritus fate (NOT the ECOTRAN parameters); note transpose to stack of horizontal vectors

ModelDefinitions.ExcretionFate                   = ExcretionFate; % row 1 = surface mixed layer; row 2 = sub-surface; (2 horizontal vectors)
ModelDefinitions.PhytoUptake_NO3                 = PhytoUptake_NO3; % row 1 = fraction of NO3 to small phytoplankton; row 2 = fraction of NO3 to large phytoplankton; (vertical vector)
ModelDefinitions.PhytoUptake_NH4                 = PhytoUptake_NH4; % row 1 = fraction of NH4 to small phytoplankton; row 2 = fraction of NH4 to large phytoplankton; (vertical vector)
ModelDefinitions.Oxidation_NH4                   = Oxidation_NH4; % fraction of NH4 produced oxidized directly back to NO3 abiologically; this should take precedence over phytoplankton uptake of NH4 in code below; (vertical vector)

ModelDefinitions.GroupType                       = GroupType;
ModelDefinitions.GroupType_nutrients             = GroupType_nutrients;
ModelDefinitions.GroupType_EggsAndDetritus       = GroupType_EggsAndDetritus;
ModelDefinitions.AggLabel                        = AggLabel;
ModelDefinitions.AggLabel_nutrients              = AggLabel_nutrients;
ModelDefinitions.AggLabel_EggsAndDetritus        = AggLabel_EggsAndDetritus;
ModelDefinitions.ProductionLossScaler            = ProductionLossScaler;
ModelDefinitions.RetentionScaler                 = RetentionScaler;
ModelDefinitions.FunctionalResponseParams        = FunctionalResponseParams;

ModelDefinitions.GroupTypeDef_ANYNitroNutr       = EwEResult.GroupTypeDef_ANYNitroNutr;
ModelDefinitions.GroupTypeDef_NO3                = EwEResult.GroupTypeDef_NO3;
ModelDefinitions.GroupTypeDef_plgcNH4            = EwEResult.GroupTypeDef_plgcNH4;
ModelDefinitions.GroupTypeDef_bnthNH4            = EwEResult.GroupTypeDef_bnthNH4;
ModelDefinitions.GroupTypeDef_ANYPrimaryProd     = EwEResult.GroupTypeDef_ANYPrimaryProd;
ModelDefinitions.GroupTypeDef_LrgPhyto           = EwEResult.GroupTypeDef_LrgPhyto;
ModelDefinitions.GroupTypeDef_SmlPhyto           = EwEResult.GroupTypeDef_SmlPhyto;
ModelDefinitions.GroupTypeDef_Macrophytes        = EwEResult.GroupTypeDef_Macrophytes;
ModelDefinitions.GroupTypeDef_ANYConsumer        = EwEResult.GroupTypeDef_ANYConsumer;
ModelDefinitions.GroupTypeDef_ConsumPlgcPlankton = EwEResult.GroupTypeDef_ConsumPlgcPlankton;
ModelDefinitions.GroupTypeDef_ConsumPlgcNekton   = EwEResult.GroupTypeDef_ConsumPlgcNekton;
ModelDefinitions.GroupTypeDef_ConsumPlgcWrmBlood = EwEResult.GroupTypeDef_ConsumPlgcWrmBlood;
ModelDefinitions.GroupTypeDef_ConsumBntcInvert   = EwEResult.GroupTypeDef_ConsumBntcInvert;
ModelDefinitions.GroupTypeDef_ConsumBntcVert     = EwEResult.GroupTypeDef_ConsumBntcVert;
ModelDefinitions.GroupTypeDef_ConsumBnthWrmBlood = EwEResult.GroupTypeDef_ConsumBnthWrmBlood;
ModelDefinitions.GroupTypeDef_eggs               = EwEResult.GroupTypeDef_eggs;
ModelDefinitions.GroupTypeDef_ANYDetritus        = EwEResult.GroupTypeDef_ANYDetritus;
ModelDefinitions.GroupTypeDef_terminalPlgcDetr   = EwEResult.GroupTypeDef_terminalPlgcDetr;
ModelDefinitions.GroupTypeDef_offal              = EwEResult.GroupTypeDef_offal;
ModelDefinitions.GroupTypeDef_terminalBnthDetr   = EwEResult.GroupTypeDef_terminalBnthDetr;
ModelDefinitions.GroupTypeDef_BA                 = EwEResult.GroupTypeDef_BA;
ModelDefinitions.GroupTypeDef_EM                 = EwEResult.GroupTypeDef_EM;
ModelDefinitions.GroupTypeDef_fishery            = EwEResult.GroupTypeDef_fishery;
ModelDefinitions.GroupTypeDef_import             = EwEResult.GroupTypeDef_import;
ModelDefinitions.GroupTypeDef_plgcBacteria       = EwEResult.GroupTypeDef_plgcBacteria;
ModelDefinitions.GroupTypeDef_bnthBacteria       = EwEResult.GroupTypeDef_bnthBacteria;

ModelDefinitions.looky_PrimaryProducers          = looky_PrimaryProducers;
ModelDefinitions.looky_eggs                      = looky_eggs;
ModelDefinitions.looky_detritus                  = looky_detritus;
ModelDefinitions.looky_PelagicDetritus           = looky_PelagicDetritus;
ModelDefinitions.looky_BenthicDetritus           = looky_BenthicDetritus;
ModelDefinitions.looky_EggsAndDetritus           = looky_EggsAndDetritus;
ModelDefinitions.looky_fisheries                 = looky_fisheries;
ModelDefinitions.looky_consumers                 = looky_consumers;
ModelDefinitions.looky_OffalInDetritus           = looky_OffalInDetritus;
ModelDefinitions.looky_PlgcDetrInDetritus        = looky_PlgcDetrInDetritus;
ModelDefinitions.looky_BnthcDetrInDetritus       = looky_BnthcDetrInDetritus;
ModelDefinitions.looky_EggsInDetritus            = looky_EggsInDetritus;
ModelDefinitions.looky_DetrInDetritus            = looky_DetrInDetritus;
ModelDefinitions.looky_plgcBacteria              = looky_plgcBacteria;
ModelDefinitions.looky_bnthBacteria              = looky_bnthBacteria;

ModelDefinitions.num_NitrogenNutrients           = num_NitrogenNutrients;
ModelDefinitions.num_PrimaryProducers            = num_PrimaryProducers;
ModelDefinitions.num_eggs                        = num_eggs;
ModelDefinitions.num_detritus                    = num_detritus;
ModelDefinitions.num_PelagicDetritus             = num_PelagicDetritus;
ModelDefinitions.num_BenthicDetritus             = num_BenthicDetritus;
ModelDefinitions.num_EggsAndDetritus             = num_EggsAndDetritus;
ModelDefinitions.num_consumers                   = num_consumers;
ModelDefinitions.num_fisheries                   = num_fisheries;
ModelDefinitions.num_bacteria                    = num_bacteria;
ModelDefinitions.num_ECOTRAN_groups              = num_ECOTRAN_groups;

ModelDefinitions.MonteCarlo_rows                 = MonteCarlo_rows;
ModelDefinitions.MonteCarlo_layers               = MonteCarlo_layers;
ModelDefinitions.MonteCarloDiet_rows             = MonteCarloDiet_rows;
ModelDefinitions.MonteCarloDiet_clms             = MonteCarloDiet_clms;





% *************************************************************************
% STEP 4: initialize ECOTRAN results structure-----------------------------
ECOTRAN.EnergyBudget_matrix                 = zeros(num_ECOTRAN_groups, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.BioenergeticBudget                  = zeros(3, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.BioenergeticBudget_ProductionDetail = zeros(5, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.BioenergeticBudget_OtherMortDetail  = zeros(num_detritus, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.BioenergeticBudget_FecesDetail      = zeros(num_detritus, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.ProductionBudget                    = zeros(5, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.ProductionBudget_OtherMortDetail    = zeros(num_detritus, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.GroupType                           = zeros((num_ECOTRAN_groups+2), 1); % same for all MonteCarlo models
ECOTRAN.AggLabel                            = cell((num_ECOTRAN_groups+2), 1); % same for all MonteCarlo models
ECOTRAN.GroupType_detritus                  = zeros(num_detritus, 1); % same for all MonteCarlo models
ECOTRAN.AggLabel_detritus                   = cell(num_detritus, 1); % same for all MonteCarlo models
ECOTRAN.EwE_Biomass                         = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_PB                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_QB                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_PQ                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_AE                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_BA                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_EM                              = zeros(num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.DetritusFate_feces                  = zeros(2, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.DetritusFate_senescence             = zeros(2, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.ExcretionFate                       = zeros(2, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EggFate                             = zeros(num_eggs, num_ECOTRAN_groups, MonteCarlo_layers);
ECOTRAN.EwE_Landings                        = zeros(num_ECOTRAN_groups, num_fisheries, MonteCarlo_layers);
ECOTRAN.EwE_Discards                        = zeros(num_ECOTRAN_groups, num_fisheries, MonteCarlo_layers);
ECOTRAN.EwE_TotalFishery                    = zeros(num_ECOTRAN_groups, num_fisheries, MonteCarlo_layers);
ECOTRAN.EcotrophicEfficiency_predation      = zeros(MonteCarlo_layers, num_ECOTRAN_groups);
ECOTRAN.EcotrophicEfficiency_BA             = zeros(MonteCarlo_layers, num_ECOTRAN_groups);
ECOTRAN.EcotrophicEfficiency_EM             = zeros(MonteCarlo_layers, num_ECOTRAN_groups);
ECOTRAN.EcotrophicEfficiency                = zeros(MonteCarlo_layers, num_ECOTRAN_groups);
ECOTRAN.TransferEfficiency                  = zeros(MonteCarlo_layers, num_ECOTRAN_groups);
% (FFF in future, could also return EwE_diet here)





% *************************************************************************
% STEP 5: perform ECOTRAN conversion for each MonteCarlo model-------------
for layer_loop = 1:MonteCarlo_layers
    
    % step 5a: select current MonteCarlo level ----------------------------
    CurrentModel.EwE_Biomass         = EwE_Biomass(:, layer_loop);
    CurrentModel.EwE_PB              = EwE_PB(:, layer_loop);
    CurrentModel.EwE_QB              = EwE_QB(:, layer_loop);
    CurrentModel.EwE_PQ              = EwE_PQ(:, layer_loop);
    CurrentModel.EwE_AE              = EwE_AE(:, layer_loop);
    CurrentModel.EwE_BA              = EwE_BA(:, layer_loop);
    CurrentModel.EwE_EM              = EwE_EM(:, layer_loop);
    CurrentModel.EwE_EE              = EwE_EE(:, layer_loop);
    CurrentModel.working_diet        = working_diet(:, :, layer_loop);
    CurrentModel.working_consumption = working_consumption(:, :, layer_loop);
    CurrentModel.EwE_Landings        = EwE_Landings(:, :, layer_loop); % (t/km2/y); (2D matrix: groups X gear)
    CurrentModel.EwE_Discards        = EwE_Discards(:, :, layer_loop); % (t/km2/y); (2D matrix: groups X gear
    CurrentModel.EwE_TotalFishery    = EwE_TotalFishery(:, :, layer_loop); % (t/km2/y); (2D matrix: groups X gear
    
    % step 5b: run it through ECOTRAN -------------------------------------
    [SINGLE_ECO] = f_ECOfunction_05142015(ModelDefinitions, CurrentModel); % returns a single ECOTRAN model for 1 "type" EwE model or 1 MonteCarlo EwE model
    
    % step 5c: build-up set of ECOTRAN models (QQQ could change to use more 'nums_' than ':')
    ECOTRAN.EnergyBudget_matrix(:, :, layer_loop)                             = SINGLE_ECO.BigMatrix;
    ECOTRAN.BioenergeticBudget(1:3, :, layer_loop)                            = SINGLE_ECO.BioenergeticBudget;
    ECOTRAN.BioenergeticBudget_ProductionDetail(1:5, :, layer_loop)           = SINGLE_ECO.BioenergeticBudget_ProductionDetail;
    ECOTRAN.BioenergeticBudget_OtherMortDetail(1:num_detritus, :, layer_loop) = SINGLE_ECO.BioenergeticBudget_OtherMortDetail;
    ECOTRAN.BioenergeticBudget_FecesDetail(1:num_detritus, :, layer_loop)     = SINGLE_ECO.BioenergeticBudget_FecesDetail;
    ECOTRAN.ProductionBudget(1:5, :, layer_loop)                              = SINGLE_ECO.ProductionBudget;
    ECOTRAN.ProductionBudget_OtherMortDetail(1:num_detritus, :, layer_loop)   = SINGLE_ECO.ProductionBudget_OtherMortDetail;
	ECOTRAN.EwE_Biomass(:, layer_loop)                                        = SINGLE_ECO.EwE_Biomass;
    ECOTRAN.EwE_PB(:, layer_loop)                                             = SINGLE_ECO.EwE_PB;
    ECOTRAN.EwE_QB(:, layer_loop)                                             = SINGLE_ECO.EwE_QB;
    ECOTRAN.EwE_PQ(:, layer_loop)                                             = SINGLE_ECO.EwE_PQ;
    ECOTRAN.EwE_AE(:, layer_loop)                                             = SINGLE_ECO.EwE_AE;
    ECOTRAN.EwE_BA(:, layer_loop)                                             = SINGLE_ECO.EwE_BA;    
    ECOTRAN.EwE_EM(:, layer_loop)                                             = SINGLE_ECO.EwE_EM;
    ECOTRAN.DetritusFate_feces(1:2, :, layer_loop)                            = SINGLE_ECO.DetritusFate_feces;
    ECOTRAN.DetritusFate_senescence(1:2, :, layer_loop)                       = SINGLE_ECO.DetritusFate_senescence;
    ECOTRAN.ExcretionFate(1:2, :, layer_loop)                                 = SINGLE_ECO.ExcretionFate;
    ECOTRAN.EggFate(:, :, layer_loop)                                         = SINGLE_ECO.EggFate;
    ECOTRAN.EwE_Landings(:, :, layer_loop)                                    = SINGLE_ECO.EwE_Landings; % (t/km2/y); (3D matrix: groups X gear X layer)
    ECOTRAN.EwE_Discards(:, :, layer_loop)                                    = SINGLE_ECO.EwE_Discards; % (t/km2/y); (3D matrix: groups X gear X layer)
    ECOTRAN.EwE_TotalFishery(:, :, layer_loop)                                = SINGLE_ECO.EwE_TotalFishery; % (t/km2/y); (3D matrix: groups X gear	X layer)
    ECOTRAN.EcotrophicEfficiency_predation(layer_loop, :)                     = SINGLE_ECO.EcotrophicEfficiency_predation;
    ECOTRAN.EcotrophicEfficiency_BA(layer_loop, :)                            = SINGLE_ECO.EcotrophicEfficiency_BA;
    ECOTRAN.EcotrophicEfficiency_EM(layer_loop, :)                            = SINGLE_ECO.EcotrophicEfficiency_EM;
    ECOTRAN.EcotrophicEfficiency(layer_loop, :)                               = SINGLE_ECO.EcotrophicEfficiency;
    ECOTRAN.TransferEfficiency(layer_loop, :)                                 = SINGLE_ECO.TransferEfficiency;
    
end

% step 5d: labels and GroupTypes (QQQ add AggLabel_fisheries here) (doesn't need to be inside layer_loop because they are same for every model)
ECOTRAN.GroupType                       = SINGLE_ECO.GroupType;
ECOTRAN.AggLabel                        = SINGLE_ECO.AggLabel;
ECOTRAN.GroupType_detritus              = SINGLE_ECO.GroupType_detritus;
ECOTRAN.AggLabel_detritus               = SINGLE_ECO.AggLabel_detritus;
ECOTRAN.ProductionLossScaler            = SINGLE_ECO.ProductionLossScaler;
ECOTRAN.RetentionScaler                 = SINGLE_ECO.RetentionScaler;
ECOTRAN.FunctionalResponseParams        = SINGLE_ECO.FunctionalResponseParams;

ECOTRAN.GroupTypeDef_ANYNitroNutr       = ModelDefinitions.GroupTypeDef_ANYNitroNutr;
ECOTRAN.GroupTypeDef_NO3                = ModelDefinitions.GroupTypeDef_NO3;
ECOTRAN.GroupTypeDef_plgcNH4            = ModelDefinitions.GroupTypeDef_plgcNH4;
ECOTRAN.GroupTypeDef_bnthNH4            = ModelDefinitions.GroupTypeDef_bnthNH4;
ECOTRAN.GroupTypeDef_ANYPrimaryProd     = ModelDefinitions.GroupTypeDef_ANYPrimaryProd;
ECOTRAN.GroupTypeDef_LrgPhyto           = ModelDefinitions.GroupTypeDef_LrgPhyto;
ECOTRAN.GroupTypeDef_SmlPhyto           = ModelDefinitions.GroupTypeDef_SmlPhyto;
ECOTRAN.GroupTypeDef_Macrophytes        = ModelDefinitions.GroupTypeDef_Macrophytes;
ECOTRAN.GroupTypeDef_ANYConsumer        = ModelDefinitions.GroupTypeDef_ANYConsumer;
ECOTRAN.GroupTypeDef_ConsumPlgcPlankton = ModelDefinitions.GroupTypeDef_ConsumPlgcPlankton;
ECOTRAN.GroupTypeDef_ConsumPlgcNekton   = ModelDefinitions.GroupTypeDef_ConsumPlgcNekton;
ECOTRAN.GroupTypeDef_ConsumPlgcWrmBlood = ModelDefinitions.GroupTypeDef_ConsumPlgcWrmBlood;
ECOTRAN.GroupTypeDef_ConsumBntcInvert   = ModelDefinitions.GroupTypeDef_ConsumBntcInvert;
ECOTRAN.GroupTypeDef_ConsumBntcVert     = ModelDefinitions.GroupTypeDef_ConsumBntcVert;
ECOTRAN.GroupTypeDef_ConsumBnthWrmBlood = ModelDefinitions.GroupTypeDef_ConsumBnthWrmBlood;
ECOTRAN.GroupTypeDef_eggs               = ModelDefinitions.GroupTypeDef_eggs;
ECOTRAN.GroupTypeDef_ANYDetritus        = ModelDefinitions.GroupTypeDef_ANYDetritus;
ECOTRAN.GroupTypeDef_terminalPlgcDetr   = ModelDefinitions.GroupTypeDef_terminalPlgcDetr;
ECOTRAN.GroupTypeDef_offal              = ModelDefinitions.GroupTypeDef_offal;
ECOTRAN.GroupTypeDef_terminalBnthDetr   = ModelDefinitions.GroupTypeDef_terminalBnthDetr;
ECOTRAN.GroupTypeDef_BA                 = ModelDefinitions.GroupTypeDef_BA;
ECOTRAN.GroupTypeDef_EM                 = ModelDefinitions.GroupTypeDef_EM;
ECOTRAN.GroupTypeDef_fishery            = ModelDefinitions.GroupTypeDef_fishery;
ECOTRAN.GroupTypeDef_import             = ModelDefinitions.GroupTypeDef_import;
ECOTRAN.GroupTypeDef_plgcBacteria       = ModelDefinitions.GroupTypeDef_plgcBacteria;
ECOTRAN.GroupTypeDef_bnthBacteria       = ModelDefinitions.GroupTypeDef_bnthBacteria;





% end m-file***************************************************************