function [diet_trace_downward, trace_fraction_downward] = f_DietTraceDownward_03152015(EwEResult, MonteCarloStore, TraceGroup)
% trace source group flow through static model food web
% NOTE: cannibalism loops are eliminated
% by Jim Ruzicka
% takes:
%	TraceGroup                      (number code of agg group to be traced)	(scaler)
%   EwEResult
%       EwEResult.Diet              (matrix)
%       EwEResult.Landings
%       EwEResult.Discards
%       GroupTypeDefs
%   MonteCarloStore
%       MonteCarloStore.diet        (matrices in layers of MonteCarlo models)
%       MonteCarloStore.Landings
%       MonteCarloStore.Discards
% returns:
%	diet_trace_downward     (relative contribution of each linkage to production of top consumer (= TraceGroup)
%                               (3D matrix: )
%	trace_fraction_downward	(fraction of top consumer (= TraceGroup) energy (production, consumption) passing through each trophic group
%                            via all direct and indirect pathways back to phyto and/or detritus)
%                               (3D vertical vectors: )
% calls:
%	none
% revision date: 3-15-2015





% *************************************************************************
% STEP 1: set operating parameters-----------------------------------------
iteration_tolerance                = 0.0001; % iterate until working_trace stabilizes
iteration_max                      = 1000; % maximum number of iterations





% *************************************************************************
% STEP 2: get info from EwEResult and MonteCarloStore
EwE_number        = EwEResult.EwE_code';
GroupType         = EwEResult.GroupType;

if isempty(MonteCarloStore)
    Diet          = EwEResult.Diet(2:end, 2:end); % trim off diet header row and column
    TempFisheries = EwEResult.Landings + EwEResult.Discards;
else
    Diet          = MonteCarloStore.diet(2:end, 2:end, :); % trim off diet header row and column
    TempFisheries = MonteCarloStore.Landings + MonteCarloStore.Discards;
end

[toss_rows, toss_clms, num_trials] = size(Diet);





% *************************************************************************
% STEP 3: get address info-------------------------------------------------
looky_nutrients     = find(floor(GroupType) == EwEResult.GroupTypeDef_ANYNitroNutr);
looky_BA            = find(floor(GroupType) == EwEResult.GroupTypeDef_BA);
looky_EM            = find(floor(GroupType) == EwEResult.GroupTypeDef_EM);
looky_fisheries     = find(floor(GroupType) == EwEResult.GroupTypeDef_fishery);

EwE_number([looky_nutrients' looky_BA' looky_EM' looky_fisheries']) = []; % now matches EwE groups (no ECOTRAN groups: nutrients, BA & EM, fisheries)
GroupType([looky_nutrients' looky_BA' looky_EM' looky_fisheries'])  = [];
GroupType(end+1)                                                    = EwEResult.GroupTypeDef_import; % add import diet to GroupType vector





% *************************************************************************
% STEP 4: prep diet matrix-------------------------------------------------
% step 4a: 
DietPredatorType    = GroupType(1:(end-1))';
DietPredatorCode    = EwE_number';
DietPreyType        = GroupType;
DietPreyCode        = EwE_number;
DietPreyCode(end+1) = max(EwE_number) + 1; % Prey code added for import as prey (there is no import as predator)

% step 4b: append fisheries (as a diet fraction)
[fishery_rows, num_fisheries, trial_check] = size(TempFisheries); % number of separate fisheries
fishery_size                               = sum(TempFisheries, 1); % size of each fishery (t)
if (num_fisheries == num_trials) && (trial_check == 1)
    num_fisheries = 1;
    Fisheries     = zeros(fishery_rows, 1, num_trials);
    for trial_loop = 1:num_trials
        for fishery_loop = 1:fishery_rows
            Fisheries(fishery_loop, 1, trial_loop) = TempFisheries(fishery_loop, trial_loop) ./ fishery_size(trial_loop); % re-scale fishery to 1 (express as a fraction of total fishery)
        end
    end
else
    Fisheries = zeros(fishery_rows, num_fisheries, num_trials);
    for trial_loop = 1:num_trials
        for fishery_loop = 1:fishery_rows
            Fisheries(fishery_loop, :, trial_loop) = TempFisheries(fishery_loop, :, trial_loop) ./ fishery_size(1, :, trial_loop); % re-scale fishery to 1 (express as a fraction of total fishery)
        end
    end
end % ((num_fisheries == num_trials) && (trial_check == 1))
Fisheries(isnan(Fisheries)) = 0; % correct for div/0 error, change NaNs to 0
clear trial_check TempFisheries

Fisheries((end+1), :, :)                           = 0; % add import fisheries row (all are 0)
Diet(:, (end+1):(end+num_fisheries), 1:num_trials) = Fisheries; % append Fisheries as predator columns (NOTE: there is no column for "import" as predator)
Diet((end+1):(end+num_fisheries), :, 1:num_trials) = 0; % append fishery as prey rows
DietPredatorType((end+1):(end+num_fisheries))      = EwEResult.GroupTypeDef_fishery; % set fishery agg code number to 5
DietPredatorCode((end+1):(end+num_fisheries))      = max(DietPreyCode) + 1:max(DietPreyCode) + num_fisheries; % 
DietPreyType((end+1):(end+num_fisheries), 1)       = EwEResult.GroupTypeDef_fishery; % set fishery agg code number to 5
DietPreyCode((end+1):(end+num_fisheries), 1)       = max(DietPreyCode) + 1:max(DietPreyCode) + num_fisheries; % 

% step 4c: remove non-consumer predators (phyto, eggs, detritus) from diet columns
looky_phyto           = find(floor(DietPredatorType) == EwEResult.GroupTypeDef_ANYPrimaryProd);
looky_eggs            = find(DietPredatorType        == EwEResult.GroupTypeDef_eggs);
looky_detritus        = find(floor(DietPredatorType) == EwEResult.GroupTypeDef_ANYDetritus); % offal groups
looky_plgcBacteria    = find(DietPredatorType        == EwEResult.GroupTypeDef_plgcBacteria);
looky_bnthBacteria    = find(DietPredatorType        == EwEResult.GroupTypeDef_bnthBacteria);
looky_NonConsumer     = [looky_phyto looky_eggs looky_detritus looky_plgcBacteria looky_bnthBacteria];

DietNonConsumerCode                 = DietPredatorCode(looky_NonConsumer);
DietPredatorType(looky_NonConsumer) = [];
DietPredatorCode(looky_NonConsumer) = [];
Diet(:, looky_NonConsumer, :)       = [];
[Diet_rows, Diet_clms, toss]        = size(Diet);

% step 4d: remove cannibalism loops from Diet
for prey_loop = 1:Diet_rows
	current_prey = DietPreyCode(prey_loop);
	looky_pred   = find(DietPredatorCode == current_prey);
    if ~isempty(looky_pred)
		Diet(prey_loop, looky_pred, 1:num_trials) = 0;
    end
end

% step 4e: re-scale diet columns to 1
sum_diet = sum(Diet, 1);
for trial_loop = 1:num_trials
    for prey_loop = 1:Diet_rows
        Diet(prey_loop, :, trial_loop) = Diet(prey_loop, :, trial_loop) ./ sum_diet(1,:, trial_loop);
    end
end
Diet(isnan(Diet)) = 0; % correct for div/0 error, change NaNs to 0





% *************************************************************************
% STEP 5: perform top-down diet trace for each MonteCarlo model------------
% step 5a: (QQQ allow a jump out for phyto and detritus groups to give 0 values)

diet_trace_downward     = zeros(length(DietPreyCode), length(DietPreyCode), num_trials); % initialize stack of diet_trace_downward matrices
trace_fraction_downward = zeros(length(DietPreyCode), 1, num_trials); % initialize stack of trace_fraction_downward vertical vectors

if ~ismember(TraceGroup, DietNonConsumerCode)
    
    

looky_TraceGroup        = find(DietPredatorCode == TraceGroup);
if isempty(looky_TraceGroup); error('no such trophic group code number'); end

% step 5b: check alignment of predator and prey vectors
consumer_rows  = find(floor(DietPreyType) == EwEResult.GroupTypeDef_ANYConsumer | floor(DietPreyType) == EwEResult.GroupTypeDef_fishery); % identify consumer groups by row number along prey vector
CheckAlignment = max(abs(DietPreyCode(consumer_rows) - DietPredatorCode'));
if CheckAlignment ~= 0; error('prey and predator vectors are not aligned'); end


for trial_loop = 1:num_trials

    % step 5c: re-initialize for each MonteCarlo model
    current_Diet            = Diet(:, :, trial_loop);
    working_trace           = current_Diet;
    TraceVector             = zeros(1, Diet_clms); % re-initialize for each MonteCarlo model; (horizontal vector)
    trace_fraction_current  = zeros(Diet_rows, 1); % re-initialize for each MonteCarlo model; (vertical vector)
    
    trace_fraction_previous = ones(Diet_rows, 1); % initialize trace_fraction_previous (vertical vector)
    check_iteration         = 1; % initialize check_iteration
    iteration_count         = 0; % initialize iteration_count    
    
    
    
    
    % step 5d: get OriginVector using the TraceGroup
    OriginVector   = current_Diet(:, looky_TraceGroup); % TraceGroup-as-predator (vertical vector)
    
    % step 5e: prepare TraceVector (horizontal vector)
    for pred_loop = 1:Diet_clms
        current_PredatorCode      = DietPredatorCode(pred_loop);
        looky_CurrentPred         = find(DietPreyCode == current_PredatorCode); % row number of current predator in OriginVector
        TraceVector(1, pred_loop) = OriginVector(looky_CurrentPred, 1);
    end    
    TraceVector(1, looky_TraceGroup) = 1; % contribution of TraceGroup to TraceGroup itself = 1
    
    % step 5f: multiply predation on TraceGroup through diet matrix, iteratively
    while (check_iteration > iteration_tolerance) && (iteration_count < iteration_max)

        for prey_loop = 1:Diet_rows
            working_trace(prey_loop, :) = TraceVector .* current_Diet(prey_loop, :); % multiply TraceVector through the diet matrix
        end % (prey_loop)
        
        trace_fraction_current = sum(working_trace, 2); % fraction of trace group in diet of each predator (vertical vector)
        
        % make new TraceVector
        for pred_loop = 1:Diet_clms
            current_PredatorCode         = DietPredatorCode(pred_loop);
            looky_CurrentPred            = find(DietPreyCode == current_PredatorCode); % row number of current predator in OriginVector
            TraceVector(1, pred_loop)    = trace_fraction_current(looky_CurrentPred, 1);
        end % (pred_loop)
        TraceVector(1, looky_TraceGroup) = 1; % contribution of TraceGroup to TraceGroup itself = 1
        check_iteration                  = max(abs(trace_fraction_previous - trace_fraction_current));
        iteration_count                  = iteration_count + 1;
        trace_fraction_previous          = trace_fraction_current;

    end % ((check_iteration > iteration_tolerance) && (iteration_count < iteration_max))
    
    % step 5g: 
    trace_fraction_downward(1:length(DietPreyCode), 1, trial_loop)  = trace_fraction_current;
    looky_TraceGroup_AsPrey                                         = find(DietPreyCode == TraceGroup);
    trace_fraction_downward(looky_TraceGroup_AsPrey, 1, trial_loop) = 1; % set origin group to 1; % contribution of TraceGroup to TraceGroup itself = 1
    
    % step 5h: put columns of diet_trace_downward matrix in same order as trophic groups (include non-consumer groups)
    for Prey_loop = 1:length(DietPredatorCode)
        current_group       = DietPredatorCode(Prey_loop);
        looky_prey_position = find(DietPreyCode == current_group);
        if ~isempty(looky_prey_position)
            diet_trace_downward(:, looky_prey_position, trial_loop) = working_trace(:, Prey_loop);
        end % (~isempty(looky_prey_position))
    end % (Prey_loop)
    
end % (trial_loop)

end



% end m-file***************************************************************