function MonteCarlo_interval = f_EwEinterval_MonteCarlo_04092014(EwEResult, PEDIGREE)
% set up intervals for drawing Monte Carlo models
% takes:
%   EwEResult
%   PEDIGREE            (as fraction of base value for PARAMETERS & DIET; as 1 STD for BA)
%       PEDIGREE.PedigreeParameters         (37 clms)
%           clm 1:      maxEE
%           clm 2:      B (CV)
%           clm 3:      PB (CV)
%           clm 4:      QB (CV)
%           clm 5:      PQ (CV)
%           clm 6:      AE (CV)
%           clm 7-11:   min [B PB QB PQ AE] (absolute value, not CV)
%           clm 12-16:  max [B PB QB PQ AE] (absolute value, not CV)
% revision date: 4-9-2014

% *************************************************************************
% STEP 1: PARAMETER pedigree-----------------------------------------------
STD_scaler              = PEDIGREE.STD_scaler; % STD range of acceptable drawing interval
SamplingScale           = PEDIGREE.SamplingScale; % Bigger number makes STD range tighter; SamplingScale = 1 assumes the valid parameter interval represents +/- 2 STD_scaler (98% of values)
SamplingScale_Diet      = PEDIGREE.SamplingScale_Diet;
SamplingScale_Fisheries = PEDIGREE.SamplingScale_Fisheries;

% step 1a: read original EwE parameter values -----------------------------
EwE_PB                         = EwEResult.PB;
EwE_QB                         = EwEResult.QB;
EwE_PQ                         = EwEResult.PQ;
EwE_AE                         = EwEResult.AE;
EwE_MTBLSM                     = EwE_AE - EwE_PQ; % fraction of consumption going to metabolism (NH4 production); Metabolism = 1 - PQ - feces = (1 - (EwE_PQ + (1-EwE_AE)))
EwE_Biomass                    = EwEResult.Biomass;

Original_Parameters            = [EwE_PB EwE_QB EwE_PQ EwE_AE EwE_MTBLSM EwE_Biomass];
Original_Landings              = EwEResult.Landings;
Original_Discards              = EwEResult.Discards;
[Params_rows, Params_clms]     = size(Original_Parameters);
[Landings_rows, Landings_clms] = size(Original_Landings);
looky_detritus                 = find(floor(EwEResult.GroupType) == EwEResult.GroupTypeDef_ANYDetritus | floor(EwEResult.GroupType) == EwEResult.GroupTypeDef_eggs); % will need this info later; (4-1-2014 includes eggs)
looky_ANYPrimaryProd           = find(floor(EwEResult.GroupType) == EwEResult.GroupTypeDef_ANYPrimaryProd); % will need this info later
num_EwEgroups                  = length(EwEResult.GroupType);

% step 1b: read in PEDIGREE values (CV) and apply any pedigree scales -----
PEDIGREE_PB                    = PEDIGREE.PedigreeParameters(:, 3) .* PEDIGREE.PhysiologyScaler;
PEDIGREE_PQ                    = PEDIGREE.PedigreeParameters(:, 5) .* PEDIGREE.PhysiologyScaler;
PEDIGREE_AE                    = PEDIGREE.PedigreeParameters(:, 6) .* PEDIGREE.PhysiologyScaler;
PEDIGREE_Biomass               = PEDIGREE.PedigreeParameters(:, 2) .* PEDIGREE.BiomassScaler;
PEDIGREE_MinBiomassFraction    = PEDIGREE.minBiomass; % minimum fraction of original value
PEDIGREE_MinPhysiologyFraction = PEDIGREE.minPhysiology; % minimum fraction of original value

% calculate CV for non-independent parameters (QB & MTBLSM)
VAR_PB                         = (EwE_PB .* PEDIGREE_PB).^2; % variance
VAR_PQ                         = (EwE_PQ .* PEDIGREE_PQ).^2; % variance
VAR_AE                         = (EwE_AE .* PEDIGREE_AE).^2; % variance
STD_QB                         = EwE_QB .* sqrt(VAR_PB./(EwE_PB.^2) + VAR_PQ./(EwE_PQ.^2)); % MULTIPLY variances and convert to STD
STD_MTBLSM                     = sqrt(VAR_AE + VAR_PQ); % ADD variances and convert to STD
PEDIGREE_QB                    = STD_QB ./ EwE_QB .* PEDIGREE.PhysiologyScaler; % CV
PEDIGREE_MTBLSM                = STD_MTBLSM ./ EwE_MTBLSM .* PEDIGREE.PhysiologyScaler; % CV

PEDIGREE_Parameters            = [PEDIGREE_PB PEDIGREE_QB PEDIGREE_PQ PEDIGREE_AE PEDIGREE_MTBLSM PEDIGREE_Biomass];  % CV values; [PB QB PQ AE MTBLSM Biomass]

PEDIGREE_Landings              = PEDIGREE.PedigreeLandings .* PEDIGREE.FisheriesScaler; % (FFF change name to PEDIGREE.LandingsScaler)
PEDIGREE_Discards              = PEDIGREE.PedigreeDiscards .* PEDIGREE.DiscardScaler;

% for case of defined min & max parameter values
PEDIGREE_MinBiomass            = PEDIGREE.PedigreeParameters(:, 7);
PEDIGREE_MaxBiomass            = PEDIGREE.PedigreeParameters(:, 12);
PEDIGREE_BiomassRange          = PEDIGREE_MaxBiomass - PEDIGREE_MinBiomass;
PEDIGREE_MinPB                 = PEDIGREE.PedigreeParameters(:, 8);
PEDIGREE_MinPQ                 = PEDIGREE.PedigreeParameters(:, 10);
PEDIGREE_MinAE                 = PEDIGREE.PedigreeParameters(:, 11);
PEDIGREE_MaxPB                 = PEDIGREE.PedigreeParameters(:, 13);
PEDIGREE_MaxPQ                 = PEDIGREE.PedigreeParameters(:, 15);
PEDIGREE_MaxAE                 = PEDIGREE.PedigreeParameters(:, 16);
PEDIGREE_MinQB                 = PEDIGREE_MinPB ./ PEDIGREE_MaxPQ; % Q/B = P/B * Q/P
PEDIGREE_MaxQB                 = PEDIGREE_MaxPB ./ PEDIGREE_MinPQ; % Q/B = P/B * Q/P
PEDIGREE_MinMTBLSM             = PEDIGREE_MinAE - PEDIGREE_MaxPQ; % EwE_AE - EwE_PQ
PEDIGREE_MaxMTBLSM             = PEDIGREE_MaxAE - PEDIGREE_MinPQ; % EwE_AE - EwE_PQ
PEDIGREE_MinPhysiology         = [PEDIGREE_MinPB PEDIGREE_MinQB PEDIGREE_MinPQ PEDIGREE_MinAE PEDIGREE_MinMTBLSM];
PEDIGREE_MaxPhysiology         = [PEDIGREE_MaxPB PEDIGREE_MaxQB PEDIGREE_MaxPQ PEDIGREE_MaxAE PEDIGREE_MaxMTBLSM];
PEDIGREE_PhysiologyRange       = PEDIGREE_MaxPhysiology - PEDIGREE_MinPhysiology;

% step 1c: convert CV to STD ----------------------------------------------
PEDIGREE_Parameters_STD        = Original_Parameters .* PEDIGREE_Parameters; % PEDIGREE_Parameters matrix as STD values (CV * mean = STD)
PEDIGREE_Landings_STD          = Original_Landings   .* PEDIGREE_Landings; % PEDIGREE_Landings matrix as STD values (CV * mean = STD)
PEDIGREE_Discards_STD          = Original_Discards   .* PEDIGREE_Discards; % PEDIGREE_Discards matrix as STD values (CV * mean = STD)

% step 1d: find interval over which to draw random models -----------------
low_PARAMinterval              = (Original_Parameters - (STD_scaler * PEDIGREE_Parameters_STD));
high_PARAMinterval             = (Original_Parameters + (STD_scaler * PEDIGREE_Parameters_STD));
low_LANDINGSinterval           = (Original_Landings   - (STD_scaler * PEDIGREE_Landings_STD));
high_LANDINGSinterval          = (Original_Landings   + (STD_scaler * PEDIGREE_Landings_STD));
low_DISCARDSinterval           = (Original_Discards   - (STD_scaler * PEDIGREE_Discards_STD));
high_DISCARDSinterval          = (Original_Discards   + (STD_scaler * PEDIGREE_Discards_STD));

% step 1e: filter out improper biomass values from interval ---------------
if max(PEDIGREE_BiomassRange) <= 0 % test if using defined min & max range
    % set smallest allowed Biomass as 10% the base model value
    smallest_Biomass                         = EwE_Biomass * PEDIGREE_MinBiomassFraction; % set this as the smallest allowed biomass
    test_Biomass                             = low_PARAMinterval(:, 6) - smallest_Biomass;
    looky_SmallBiomass                       = find(test_Biomass < 0); % row addresses of too small minimum Biomasses
    low_PARAMinterval(looky_SmallBiomass, 6) = smallest_Biomass(looky_SmallBiomass); % reset too small Biomasses in low_PARAMinterval to the smallest allowed Biomass
else % case when using defined min & max range
    low_PARAMinterval(:, 6)                  = PEDIGREE_MinBiomass * 0.99; % extend range a little wider than established range
    high_PARAMinterval(:, 6)                 = PEDIGREE_MaxBiomass * 1.01;
    smallest_Biomass                         = low_PARAMinterval(:, 6);
end

% step 1f: filter out improper physiology values from interval ------------
if max(max(PEDIGREE_PhysiologyRange)) <= 0 % test if using defined min & max range
    % set smallest allowed physiological parameters is (1/3) base model values
    Physiology                            = Original_Parameters(:, 1:5); % [PB QB PQ AE MTBLSM]
    low_Physiology                        = low_PARAMinterval(:, 1:5);
    smallest_Physiology                   = Physiology * PEDIGREE_MinPhysiologyFraction;
    test_Physiology                       = low_Physiology - smallest_Physiology; % (2D matrix: groups X 5)
    looky_SmallPhysiology                 = find(test_Physiology < 0); % addresses of too small minimum Physiology
    low_Physiology(looky_SmallPhysiology) = smallest_Physiology(looky_SmallPhysiology); % reset too small low_Physiology to the smallest allowed low_Physiology
    low_PARAMinterval(:, 1:5)             = low_Physiology; % plug back into low_PARAMinterval
else % case when using defined min & max range
    low_PARAMinterval(:, 1:5)             = PEDIGREE_MinPhysiology * 0.99; % extend range a little wider than established range
    high_PARAMinterval(:, 1:5)            = PEDIGREE_MaxPhysiology * 1.01;
    smallest_Physiology                   = low_PARAMinterval(:, 1:5);
end

% no negative parameter or fishery values
low_PARAMinterval(low_PARAMinterval < 0)              = 0; % (clm order: [PB QB PQ AE MTBLSM B])
high_PARAMinterval(high_PARAMinterval < 0)            = 0; % (clm order: [PB QB PQ AE MTBLSM B])
low_LANDINGSinterval(low_LANDINGSinterval < 0)        = 0;
high_LANDINGSinterval(high_LANDINGSinterval < 0)      = 0;
low_DISCARDSinterval(low_DISCARDSinterval < 0)        = 0;
high_DISCARDSinterval(high_DISCARDSinterval < 0)      = 0;

% no PQ values >1
low_PARAMinterval(low_PARAMinterval(:, 3)   > 1, 3)   = 1;
high_PARAMinterval(high_PARAMinterval(:, 3) > 1, 3)   = 1;
% no AE values >1
low_PARAMinterval(low_PARAMinterval(:, 4)   > 1, 4)   = 1;
high_PARAMinterval(high_PARAMinterval(:, 4) > 1, 4)   = 1;
% no MTBLSM values >1
low_PARAMinterval(low_PARAMinterval(:, 5)   > 1, 5)   = 1;
high_PARAMinterval(high_PARAMinterval(:, 5) > 1, 5)   = 1;

% filter out NaN parameter values (this would be metabolism of primary producer and detritus groups)
low_PARAMinterval(isnan(low_PARAMinterval))           = 0; % (clm order: [PB QB PQ AE MTBLSM B])
high_PARAMinterval(isnan(high_PARAMinterval))         = 0; % (clm order: [PB QB PQ AE MTBLSM B])

% step 1x: adjust PQ intervals to prevent bad (negative) metabolism -------
low_PARAMinterval_AE     = low_PARAMinterval(:, 4);
high_PARAMinterval_AE    = high_PARAMinterval(:, 4);
low_PARAMinterval_PQ     = low_PARAMinterval(:, 3);
high_PARAMinterval_PQ    = high_PARAMinterval(:, 3);
min_MTBLSM               = zeros(Params_rows, 1);
max_MTBLSM               = high_PARAMinterval_AE; % metabolism > AE implies negative PQ
PQhigh                   = low_PARAMinterval_AE  - min_MTBLSM; % highest possible PQ to prevent negative metabolism
PQlow                    = high_PARAMinterval_AE - max_MTBLSM; % lowest possible PQ to prevent negative metabolism
high_PARAMinterval_PQ    = min([PQhigh high_PARAMinterval_PQ], [], 2);
low_PARAMinterval_PQ     = max([PQlow low_PARAMinterval_PQ], [], 2);
low_PARAMinterval(:, 3)  = low_PARAMinterval_PQ; % substitute low_PARAMinterval_PQ back into the low_PARAMinterval matrix
high_PARAMinterval(:, 3) = high_PARAMinterval_PQ; % substitute high_PARAMinterval_PQ back into the high_PARAMinterval matrix

% step 1xx: re-define PEDIGREE_Parameters_STD & PEDIGREE_Landings_STD & PEDIGREE_Discards_STD
width_PARAMinterval         = high_PARAMinterval - low_PARAMinterval;
new_PEDIGREE_Parameters_STD = width_PARAMinterval / (SamplingScale*2); % assume the valid parameter interval represents +/- 2 STD_scaler (98% of values)
PEDIGREE_Parameters_STD     = new_PEDIGREE_Parameters_STD;
width_LANDINGSinterval      = high_LANDINGSinterval - low_LANDINGSinterval;
new_PEDIGREE_Landings_STD   = width_LANDINGSinterval / (SamplingScale_Fisheries*2); % assume the valid parameter interval represents +/- 2 STD_scaler (98% of values)
PEDIGREE_Landings_STD       = new_PEDIGREE_Landings_STD;
width_DISCARDSinterval      = high_DISCARDSinterval - low_DISCARDSinterval;
new_PEDIGREE_Discards_STD   = width_DISCARDSinterval / (SamplingScale_Fisheries*2); % assume the valid parameter interval represents +/- 2 STD_scaler (98% of values)
PEDIGREE_Discards_STD       = new_PEDIGREE_Discards_STD;

% smallest allowed parameter values for normal distribution option
min_Parameters                     = zeros(Params_rows, Params_clms); % initialize
min_Parameters(1:Params_rows, 1:5) = smallest_Physiology;
min_Parameters(1:Params_rows, 6)   = smallest_Biomass; % NOTE: this is absolutely the smallest allowed B, NOT the bottom 1 STD
min_Landings                       = zeros(Landings_rows, Landings_clms);
min_Discards                       = zeros(Landings_rows, Landings_clms);





% *************************************************************************
% STEP 2: DIET pedigree----------------------------------------------------
% step 2a: read original EwE parameter values
Original_Diet                            = EwEResult.Diet(2:end, 2:end); % trim off header row and column (this still has 1 row at bottom for import diet)
PEDIGREE_Diet                            = PEDIGREE.PedigreeDiet(2:end, 2:end) * PEDIGREE.DietScaler; % trim off header row and column (this still has 1 row at bottom for import diet); (CV)
PEDIGREE_Diet_STD                        = Original_Diet .* PEDIGREE_Diet; % PEDIGREE matrix as STD values
[Diet_rows, Diet_clms]                   = size(Original_Diet);

% step 2b: find interval over which to draw random models
low_DIETinterval                         = (Original_Diet - (STD_scaler * PEDIGREE_Diet_STD));
high_DIETinterval                        = (Original_Diet + (STD_scaler * PEDIGREE_Diet_STD));

% step 2c: filter out improper values
% no negative diet values
low_DIETinterval(low_DIETinterval < 0)   = 0;
high_DIETinterval(high_DIETinterval < 0) = 0;

% no > 1 diet values
low_DIETinterval(low_DIETinterval > 1)   = 1;
high_DIETinterval(high_DIETinterval > 1) = 1;

% step 2d: re-define PEDIGREE_Diet_STD
width_DIETinterval         = high_DIETinterval - low_DIETinterval;
new_PEDIGREE_Diet_STD      = width_DIETinterval / (SamplingScale_Diet*2); % assume the valid parameter interval represents +/- 2 STD_scaler (98% of values)
PEDIGREE_Diet_STD          = new_PEDIGREE_Diet_STD;



% *************************************************************************
% STEP 3: BIOMASS ACCUMULATION (BA) & EMIGRATION (EM) pedigree-------------
% NOTE: these are the BA & EM defined in original EwE model, not those that may be redefined for ECOTRAN
% step 3a: read original EwE parameter values
Original_BA       = EwEResult.BA; % (t/km/y) (vertical vector)
Original_EM       = EwEResult.EM; % immigration is NEGATIVE, emigration is POSITIVE (t/km/y) (vertical vector)
Original_EM(looky_detritus) = 0; % set all detritus EM to 0

PEDIGREE_BA       = (PEDIGREE.PedigreeParameters(:, 17) * PEDIGREE.BAScaler); % (CV)
PEDIGREE_EM       = (PEDIGREE.PedigreeParameters(:, 18) * PEDIGREE.EMScaler); % (CV)
PEDIGREE_BA_STD   = Original_BA .* PEDIGREE_BA; % (CV * mean = STD)
PEDIGREE_EM_STD   = Original_EM .* PEDIGREE_EM; % (CV * mean = STD)

% step 3b: find BA & EM interval over which to draw random models
low_BAinterval    = min([(Original_BA - PEDIGREE_BA_STD) (Original_BA + PEDIGREE_BA_STD)], [], 2);
high_BAinterval   = max([(Original_BA - PEDIGREE_BA_STD) (Original_BA + PEDIGREE_BA_STD)], [], 2);
low_EMinterval    = min([(Original_EM - PEDIGREE_EM_STD) (Original_EM + PEDIGREE_EM_STD)], [], 2);
high_EMinterval   = max([(Original_EM - PEDIGREE_EM_STD) (Original_EM + PEDIGREE_EM_STD)], [], 2);

% step 3c: combine BA & EM vectors
Original_BAEM     = [Original_BA Original_EM];
PEDIGREE_BAEM_STD = [PEDIGREE_BA_STD PEDIGREE_EM_STD]; % (NOTE: by ECOTRAN convention, BA comes before EM)
low_BAEMinterval  = [low_BAinterval low_EMinterval];
high_BAEMinterval = [high_BAinterval high_EMinterval];
[BAEM_rows, toss] = size(Original_BAEM);

% step 3d: filter out improper values
% NOTE: there are no improper values of BA & EM (they can be positive or negative)





% *************************************************************************
% STEP 4: pack up intervals for export-------------------------------------
MonteCarlo_interval.Original_Parameters     = Original_Parameters; % [EwE_PB EwE_QB EwE_PQ EwE_AE EwE_MTBLSM EwE_Biomass];
MonteCarlo_interval.Original_Landings       = Original_Landings;
MonteCarlo_interval.Original_Discards       = Original_Discards;
MonteCarlo_interval.Original_Diet           = Original_Diet;
MonteCarlo_interval.Original_BAEM           = Original_BAEM;

MonteCarlo_interval.Landings_rows           = Landings_rows;
MonteCarlo_interval.Landings_clms           = Landings_clms;
MonteCarlo_interval.Diet_rows               = Diet_rows;
MonteCarlo_interval.Diet_clms               = Diet_clms;

MonteCarlo_interval.PEDIGREE_Parameters_STD = PEDIGREE_Parameters_STD; % PEDIGREE_Parameters matrix as STD values (CV * mean = STD)
MonteCarlo_interval.PEDIGREE_Landings_STD   = PEDIGREE_Landings_STD; % PEDIGREE_Landings matrix as STD values (CV * mean = STD)
MonteCarlo_interval.PEDIGREE_Discards_STD   = PEDIGREE_Discards_STD; % PEDIGREE_Discards matrix as STD values (CV * mean = STD)
MonteCarlo_interval.PEDIGREE_Diet_STD       = PEDIGREE_Diet_STD;

MonteCarlo_interval.Params_rows             = Params_rows;
MonteCarlo_interval.Params_clms             = Params_clms;

MonteCarlo_interval.low_PARAMinterval       = low_PARAMinterval;
MonteCarlo_interval.high_PARAMinterval      = high_PARAMinterval;

MonteCarlo_interval.low_LANDINGSinterval    = low_LANDINGSinterval;
MonteCarlo_interval.high_LANDINGSinterval   = high_LANDINGSinterval;

MonteCarlo_interval.low_DISCARDSinterval    = low_DISCARDSinterval;
MonteCarlo_interval.high_DISCARDSinterval   = high_DISCARDSinterval;

MonteCarlo_interval.low_DIETinterval        = low_DIETinterval;
MonteCarlo_interval.high_DIETinterval       = high_DIETinterval;

MonteCarlo_interval.low_BAinterval          = low_BAinterval;
MonteCarlo_interval.high_BAinterval         = high_BAinterval;
MonteCarlo_interval.low_EMinterval          = low_EMinterval;
MonteCarlo_interval.high_EMinterval         = high_EMinterval;

MonteCarlo_interval.PEDIGREE_BAEM_STD       = PEDIGREE_BAEM_STD;
MonteCarlo_interval.low_BAEMinterval        = low_BAEMinterval;
MonteCarlo_interval.high_BAEMinterval       = high_BAEMinterval;
MonteCarlo_interval.BAEM_rows               = BAEM_rows;

MonteCarlo_interval.looky_detritus          = looky_detritus; % includes eggs
MonteCarlo_interval.looky_ANYPrimaryProd    = looky_ANYPrimaryProd;
MonteCarlo_interval.STD_scaler              = STD_scaler;

MonteCarlo_interval.num_EwEgroups           = num_EwEgroups;


% end m-file***************************************************************