function [ECOTRANphysics] = f_ECOTRANphysics_basin_08022018(PHYSICSinput)
% return Advection and Mixing exchanges between boxes
% use for NorSea basin setting
% takes:
%       internally defined time-series of advection & mixing rates
% returns ECOTRANphysics:
%       AdvectionMatrix         advection rate = volume transported per day; (m3/d)
%                               (3D matrix: time X  source boxes X destination boxes)
%                               (values can be positive or negative)
%       VerticalMixMatrix       vertical mixing rate = volume mixed per day; (m3/d)
%                               (3D matrix: time X  source boxes X destination boxes)
%                               (values can be positive or negative; sign defines direction of net mixing)
% calls:
%       round2                  (round to a specified number of decimal places)
%       f_LightIntensity
% NOTE: What happens in cases when there is a complete advective washout of a spatial box?)
%       I added cap to advection rate to prevent >100% box washout (but do not account for river flux)
%       Added warning for days when AdvectionMatrix > BoxVolume; see ECOTRANphysics.BoxWashoutTime
% revision date: 8-2-2018


% *************************************************************************
% STEP 1: basic domain parameters (NorSea basin)---------------------------
% step 1a: physical parameters --------------------------------------------
latitude     = 57;                      % latitude at middle of domain
rho_water    = 1026;                    % seawater density; (kg/m3)
rho_air      = 1.220;                   % air density (kg/m3) (Schwing et al. 1996)
% coriollis    = [];                      % coriollis factor (1/s)
midmonth_doy = [15 45 74 105 135 166 196 227 258 288 319 349]; % mid-month day-of-year

% step 1b: time domain and vectors ----------------------------------------
datestart    = PHYSICSinput.datestart;  % enter starting date
dateend      = PHYSICSinput.dateend;    % enter ending date
dt           = PHYSICSinput.dt;         % t-step (d)
t_grid       = PHYSICSinput.t_grid;     % t_grid; (vertical vector)
num_t        = length(t_grid);          % length of t_grid; (scaler)
min_t        = min(t_grid);
max_t        = max(t_grid);
num_years    = ceil(max_t/365);

% step 1c: Box ID info ----------------------------------------------------
num_boxes                   = 5;        % I, II, III, IV, V
num_AdvecFluxes             = 6;        % advective fluxes: A_12, A_13, A_24, A_35, A_4offshore, A_5offshore
num_MixFluxes               = 2;        % vertical mix fluxes: u_23, u_45
num_HorizMixFluxes          = 6;        % horizontal mix fluxes: u_12 u_13 u_24 u_35 u_4ocean u_5ocean
looky_SubSurfaceBoxes       = [3, 5];
looky_SurfaceBoxes          = [2, 4];
looky_OffshoreSurfaceBox    = 4;
looky_OffshoreSubSurfaceBox = 5;
looky_RiverFluxBox          = 1;        % River input from alongshore; (Box 2 in CGoA downwelling model)

% step 1d: spatial dimensions ---------------------------------------------
%          NOTE: Mixed Layer Depth (only used for light intensity calculations, not used for advection rate calculations)
%          NOTE: box geometry with slanty bottom
maxMLD                      = 30;                                                       % max MLD; (m)
minMLD                      = 30;                                                       % min MLD; (m)
rangeMLD                    = maxMLD - minMLD;                                          % set minimum mixed layer depth and annual range of the mixed layer depth; (m)
MLD                         = (cos(((t_grid/365)*pi)*2) * (rangeMLD * 0.5) + (minMLD + rangeMLD * 0.5)); % MLD; (m); (vertical vector: time X 1)
BoxLength                   = [10000, 425000, 425000, 10000, 10000];                    % North-South axis for NorSea; (m); I, II, III, IV, V; NOTE: estimated mean box 2 & 3 lengths of 425km from S. Ruzicka
BoxLength                   = repmat(BoxLength, [num_t, 1]);                            % (m); (2D matrix: time X num_boxes)
BoxWidth                    = [458000, 458000, 458000, 458000, 458000];                 % East-West axis for NorSea; (m); I, II, III, IV, V; NOTE: estimated mean box 2 & 3 widths of 545km from S. Ruzicka; 458km is calculated from F. Bahr's given that the AREA of box 2 & 3 is 1946000km2
BoxWidth                    = repmat(BoxWidth, [num_t, 1]);                             % (m); (2D matrix: time X num_boxes)
BoxHeight_inshore           = [MLD, MLD, (60-MLD), MLD, (60-MLD)];                      % (m); (2D matrix: time X num_boxes); I, II, III, IV, V; NOTE: 50m isobath runs diagonally across middle of domain
BoxHeight_offshore          = [MLD, MLD, (60-MLD), MLD, (60-MLD)];                      % (m); (2D matrix: time X num_boxes); I, II, III, IV, V; NOTE: 50m isobath runs diagonally across middle of domain
BoxHeight                   = 0.5 * (BoxHeight_inshore + BoxHeight_offshore);           % mean box height; (m); (2D matrix: time X num_boxes); I, II, III, IV, V
BoxArea                     = BoxHeight .* BoxLength;                                   % (m2); area as seen from the side; (2D matrix: time X num_boxes); I, II, III, IV, V
BoxVolume                   = BoxArea .* BoxWidth;                                      % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes);





% *************************************************************************
% STEP 2: prepare advection & mixing parameters----------------------------
% step 2a: Heath Physics raw values (NorSea basin) ------------------------
% monthly mean volume transport through Aberdeen-Hanstholm line (Sv = 10^6 m^3/s)
%	NOTE: northward is positive, southward is negative, up is positive, down is negative
%   NOTE: North Sea advection rates are provided as total volume advected horizontally across 
%         the Aberdeen-Hanstholm line in Sv (10^6 m^3/s). For each box, two vectors are provided, 
%         the inflow to the south (Qvol_inflow; has a negative sign) and outflow to the north 
%         (Qvol_outflow; has a positive sign). Therefore, the net horizontal flow into each model 
%         domain box across the AH-line is Qvol_net = Qvol_inflow + Qvol_outflow. Qvol_net has a 
%         positive sign for northerly outflow and negative sign for southerly inflow. I assume that 
%         sub-surface box horizontal inflow and outflow must imply upwelling or downwelling between 
%         the surface and subsurface boxes. I.e., there is NO FLOW across the southern North Sea domain 
%         boundary other than the defined river input into the surface box (always positive). 
%         I believe I have set this up correctly because I have conservation of volume in both 
%         surface and sub-surface boxes in all 12 months.
Qvol_box1_inflow  = [-0.489073065 -0.391727148 -0.362565345 -0.255441837 -0.23252799 -0.257270703 -0.281635245 -0.284808141 -0.361160811 -0.409698112 -0.465705639 -0.464118173]; % (10^6 m^3/s)
Qvol_box1_outflow = [0.685034343 0.505269148 0.454134655 0.246548903 0.226710899 0.196433001 0.233940681 0.285723341 0.366994745 0.499922258 0.583848065 0.613863308]; % (10^6 m^3/s)
Qvol_box1         = Qvol_box1_inflow + Qvol_box1_outflow;	% net volume transport; (10^6 m^3/s)
Qvol_box1         = Qvol_box1 * 10^6;                       % net volume transport; (m^3/s)

Qvol_box2_inflow  = [-0.445434176 -0.332438259 -0.283943123 -0.15113443 -0.137170583 -0.098224406 -0.11840006 -0.151365548 -0.182873774 -0.268688853 -0.332174157 -0.371892247]; % (10^6 m^3/s)
Qvol_box2_outflow = [0.257382491 0.225822852 0.198945766 0.165456311 0.147333121 0.16282189	0.169483274	0.153773341	0.180672523	0.183151888	0.219714732	0.229011456]; % (10^6 m^3/s)
Qvol_box2         = Qvol_box2_inflow + Qvol_box2_outflow;	% net volume transport; (10^6 m^3/s)
Qvol_box2         = Qvol_box2 * 10^6;                       % net volume transport; (m^3/s)


Qvol_sign         = [Qvol_box1; Qvol_box2]; % used for indicating ocean source boxes; (m^3/s); (2D matrix: num_boxes X 12 months)
Qvol              =   [ zeros(1, 12)      % flux A_12       NOTE: this is handled by river flux, set to 0
                        Qvol_box2 * (-1)  % flux A_23       NOTE: this changed for NorSea from A_13 to A_23; NOTE change in sign, when flow is northward then this becomes downwelling
                        Qvol_box1         % flux A_24
                        Qvol_box2         % flux A_35
                        Qvol_box1         % flux A_4ocean
                        Qvol_box2];       % flux A_5ocean   (m^3/s); (2D matrix: num_AdvecFluxes X 12 months)

tau               = zeros(12, 1);         % not used for NorSea model; Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (vertical vector: 12 X 1)
tau_doy           = zeros(num_t, 1);      % not used for NorSea model; Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (vertical vector: num_t X 1)


% river infux (Qr); (m3/s per 1m BoxWidth) --------------------------------
%                 NOTE: River contribution to flux A_1ocean is ALREADY accounted for in Qvol
Qr              = [0.007909594 0.006926595 0.006571952 0.005428947 0.004345449 0.003759782 0.003388651 0.003322992 0.003632684 0.004687181 0.005683 0.006864342]; % monthly mean river-driven advection rate; (10^6 m^3/s); (horizontal vector: 1 X 12 months)
Qr              = Qr * 10^6; % net volume transport; (m^3/s)
Qr              = repmat(Qr, [num_AdvecFluxes, 1]) .* repmat([(1); (0); (0); (0); (0); (0)], [1, 12]); % (m^3/s); (2D matrix: num_AdvecFluxes X 12 months)

% Horizontal mixing rate, Qe = (m3/s per 1 m BoxWidth) = (m2/s) -----------
%       NOTE: no horizontal mixing in NorSea physical model
ue                                  = zeros(num_t, num_AdvecFluxes);        % horizontal mixing rate, monthly mean: (m3/s); (2d matrix: time X num_AdvecFluxes)
ue_doy                              = zeros(num_t, num_AdvecFluxes);        % horizontal mixing rate, monthly mean: (m3/s); (2d matrix: time X num_AdvecFluxes)
HorizontalMixMatrix                 = zeros(num_t, num_boxes, num_boxes);   % mixing rate = volume mixed per day; (m3/d); (3D matrix: time X source box X destination box)
HorizontalMix_OffshoreSurface       = zeros(num_t, 1);                      % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
HorizontalMix_OffshoreSubSurface    = zeros(num_t, 1);                      % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)

% vertical mixing rates ---------------------------------------------------
% NorSea numbers
k_23        = [0.015977857 0.01942371 0.011056704 0.005231055 0.001091132 0.000434647 0.000356892 0.000511955 0.001292598 0.006459199 0.010444256 0.013587843]; % (m^2/s)
we          = k_23;     % w_23; (m^2/s); (2D matrix: flux X month)
we          = we / 30;  % (m/s); the difference in depth should be between mid-depths of the upper and lower layers. That means dividing by depth/2 (= 30 m) rather than full depth (= 60m)
we          = repmat(we, [num_MixFluxes, 1]); % (2D matrix: num_MixFluxes X 12 months); Advection Fluxes: w_23 w_45; (m/s)

% allow for cyclical repeats over several years ---------------------------
build_midmonth_doy = [];
build_Qvol         = [];
build_Qr           = [];
build_we           = [];
for year_loop = 1:num_years
    build_midmonth_doy = [build_midmonth_doy (midmonth_doy + (365 * (year_loop - 1)))];
    build_Qvol         = [build_Qvol Qvol];     % (m^3/s); (2D matrix: num_AdvecFluxes X months)
    build_Qr           = [build_Qr Qr];         % (m^3/s); (2D matrix: num_AdvecFluxes X months)
    build_we           = [build_we we];         % (m^2/s); (2D matrix: num_MixFluxes X months); (m3/s per 1m BoxWidth)
end

% step 2b: interpolate monthly means to daily values ----------------------
Qvol_doy     = interp1([1 build_midmonth_doy (365*num_years)]', [mean(Qvol(:, [1 12]), 2) build_Qvol mean(Qvol(:, [1 12]), 2)]', t_grid', 'spline');    % (m^3/s); (2D matrix: num_t X num_AdvecFluxes)
Qr_doy       = interp1([1 build_midmonth_doy (365*num_years)]', [mean(Qr(:,   [1 12]), 2) build_Qr mean(Qr(:,     [1 12]), 2)]', t_grid', 'spline');    % (m^3/s); (2D matrix: num_t X num_AdvecFluxes)
we_doy       = interp1([1 build_midmonth_doy (365*num_years)]', [mean(we(:,   [1 12]), 2) build_we mean(we(:,     [1 12]), 2)]', t_grid', 'spline');    % (m^2/s)(2D matrix: num_t X num_MixFluxes)
% we_doy       = we_doy / 2; % NOTE: division by 1/2 already accounted for in original calculation of rates; vertical mixing extends 1/2 into top box & 1/2 into bottom box

we_doy(we_doy < 0) = 0; % filter out negative vertical mixing (we) values created during spline interpolation; (2D matrix: num_t X num_AdvecFluxes); (m3/s per 1m BoxWidth)
ue_doy(ue_doy < 0) = 0; % filter out negative horizontal mixing (ue) values created during spline interpolation;   (2D matrix: num_t X num_AdvecFluxes); (m3/s per 1m BoxWidth)

% step 2c: put a limit on AdvecFluxRate and RiverFluxRate to prevent total washout of small boxes on extreme days
%          NOTE: still possible to have box washed out if RiverFluxRate tips the balance
max_AdvecFluxRate                = min((BoxVolume * 1/(60*60*24)), [], 2); % max absolute advection rate (m3/s) = one BoxVolume per day; (vertical vector)
max_AdvecFluxRate                = repmat(max_AdvecFluxRate, [1, num_AdvecFluxes]);
looky_WashoutTime                = find(abs(Qvol_doy) > max_AdvecFluxRate);
Qvol_doy(looky_WashoutTime)      = sign(Qvol_doy(looky_WashoutTime)) .* max_AdvecFluxRate(looky_WashoutTime);
looky_WashoutTime                = find(abs(Qr_doy) > max_AdvecFluxRate);
Qr_doy(looky_WashoutTime)        = sign(Qr_doy(looky_WashoutTime)) .* max_AdvecFluxRate(looky_WashoutTime);





% *************************************************************************
% STEP 3: define Advective fluxes and River fluxes to use for TimeSeries---
% step 3a:  ---------------------------------------------------------------
Advection_TimeSeries        = Qvol_doy;     % (m^3/s); (2D matrix: num_t X num_AdvecFluxes); Advection Fluxes: A_12 A_23 A_24 A_35 A_4ocean A_5ocean; NOTE: north is POSITIVE, south is NEGATIVE
RiverFlux_TimeSeries        = Qr_doy;       % (m^3/s); (2D matrix: num_t X num_AdvecFluxes); Advection Fluxes: A_12 A_23 A_24 A_35 A_4ocean A_5ocean; NOTE: north is POSITIVE, south is NEGATIVE
VerticalMixing_TimeSeries   = we_doy;       % (m^2/s); (2D matrix: num_t X num_MixFluxes); Mixing Fluxes:    M_23 M_45; NOTE: all POSITIVE & already divided 1/2 upward and 1/2 downward
% HorizontalMixing_TimeSeries = ue_doy;       % (m^2/s); (2D matrix: time X num_HorizMixFluxes); Mixing Fluxes:    u_12 u_13 u_24 u_35 u_4ocean u_5ocean;       NOTE: all POSITIVE & already divided 1/2 shoreward and 1/2 oceanward




% *************************************************************************
% STEP 4: Physical Structure (NorSea basin)--------------------------------
% step 4a: define advective connections between boxes (3D matrix: destination boxes X source boxes X specific advection flux)
%          NOTE: the sign is used to identify source box depending on onshore-vs-offshore flux
AdvcDirectionSwitch(1:5, 1:5, 1) = [
1	-1	0	0	0
1	-1	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % A_12 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 2) = [
0	0	0	0	0
0	-1	1	0	0
0	-1	1	0	0
0	0	0	0	0
0	0	0	0	0]; % A_23 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 3) = [
0	0	0	0	0
0	1	0	-1	0
0	0	0	0	0
0	1	0	-1	0
0	0	0	0	0]; % A_24 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	1	0	-1
0	0	0	0	0
0	0	1	0	-1]; % A_35 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	1	0
0	0	0	0	0]; % A_4ocean (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 6) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	1]; % A_5ocean (matrix: spatial cell X spatial cell: I II III IV V)


% step 4b: assign proper sign to advective flux (3D matrix: destination boxes X source boxes X specific advection flux)
%          NOTE: AdvectionSign refers to whether a flux is a gain or a loss to a box, it does not refer to a onshore/offshore direction
AdvectionSign(1:5, 1:5, 1) = [
-1	-1	0	0	0
1	1	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % A_12 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 2) = [
0	0	0	0	0
0	1	1	0	0
0	-1	-1	0	0
0	0	0	0	0
0	0	0	0	0]; % A_23 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 3) = [
0	0	0	0	0
0	-1	0	-1	0
0	0	0	0	0
0	1	0	1	0
0	0	0	0	0]; % A_24 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	-1	0	-1
0	0	0	0	0
0	0	1	0	1]; % A_35 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	-1	0
0	0	0	0	0]; % A_4ocean (matrix: spatial cell X spatial cell: I II III IV V); (produces offshore loss to ocean)

AdvectionSign(1:5, 1:5, 6) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	-1]; % A_5ocean (matrix: spatial cell X spatial cell: I II III IV V); (produces offshore loss to ocean)


% step 4c: define vertical mixing connections between boxes (3D matrix: DestinationBoxes X SourceSoxes X mixing flux)
VerticalMixingLink(1:5, 1:5, 1) = [
0	0	0	0	0
0	0	1	0	0
0	1	0	0	0
0	0	0	0	0
0	0	0	0	0]; % w_23

VerticalMixingLink(1:5, 1:5, 2) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % w_45; NOTE: w_45 flux is set to 0 in NorSea

% VerticalMixingLink(1:5, 1:5, 2) = [
% 0	0	0	0	0
% 0	0	0	0	0
% 0	0	0	0	0
% 0	0	0	0	1
% 0	0	0	1	0]; % w_45


% step 4f: define sinking connections between boxes (3D matrix: DestinationBoxes X SourceSoxes X sinking flux)
SinkLink(1:5, 1:5, 1) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % S_1benthos

SinkLink(1:5, 1:5, 2) = [
0	0	0	0	0
0	-1	0	0	0
0	1	0	0	0
0	0	0	0	0
0	0	0	0	0]; % S_23

SinkLink(1:5, 1:5, 3) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	-1	0
0	0	0	1	0]; % S_45

SinkLink(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	-1	0	0
0	0	0	0	0
0	0	0	0	0]; % S_3benthos

SinkLink(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	-1]; % S_5benthos





% *************************************************************************
% STEP 5: net advection & mixing gains/losses to/from each box for each t--
AdvectionMatrix                  = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
RiverFluxMatrix                  = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
VerticalMixMatrix                = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
OceanSourceBoxID                 = zeros(num_t, 1);                    % initialize; (vertical vector)

for time_loop = 1:num_t % FFF can vectorize all this in future to speed things up
    
    current_BoxWidth                     = BoxWidth(time_loop, :);                  % (m);  (horizontal vector: length num_boxes)
    current_BoxLength                    = BoxLength(time_loop, :);                 % (m);  (horizontal vector: length num_boxes)
    current_BoxHeight                    = BoxHeight(time_loop, :);                 % (m);  (horizontal vector: length num_boxes)
    current_BoxArea                      = BoxArea(time_loop, :);                   % (m);  (horizontal vector: length num_boxes)
    
    % step 5b: advection --------------------------------------------------
    current_advection                    = Advection_TimeSeries(time_loop, :);                                  % (m^3/s); (horizontal vector: 1 X num_AdvecFluxes)
    current_advection                    = reshape(current_advection, 1, 1, num_AdvecFluxes);                   % (m^3/s); (vector-along-layers: 1 X 1 X num_AdvecFluxes)
    advection_repmat                     = repmat(current_advection, [num_boxes, num_boxes, 1]);                % (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    SwitchResult                         = AdvcDirectionSwitch .* advection_repmat;                             % value is negative where flow direction is wrong @ t; (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    looky_negative                       = find(SwitchResult <= 0);                                             % find zero or backwards flow entries in matrix
    advection_repmat(looky_negative)     = 0;                                                                   % set fluxes in source box clms to 0; (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    advection_repmat                     = advection_repmat .* AdvectionSign;                                   % put correct sign on direction of flux (offshore is "+"); (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    AdvectionMatrix_temp                 = sum(advection_repmat, 3) * (60*60*24);                               % advection rate; (m^3/d); (2D matrix: DestinationBox X SourceBox)
                                                                                                                % sum all the individual advection fluxes into and out of each "destination" box
% % % %     AdvectionMatrix_temp                 = AdvectionMatrix_temp ./ repmat(current_BoxWidth', [1, num_boxes]);   % QQQ (m3/d); scale by BoxWidth; (2D matrix: DestinationBox X SourceBox);;
    AdvectionMatrix(time_loop, :, :)     = reshape(AdvectionMatrix_temp', [1, num_boxes, num_boxes]);           % (m^3/d); (3D matrix: time X SourceBox X DestinationBox)
    
    % step 5c: riverine advection -----------------------------------------
    current_RiverFlux                    = RiverFlux_TimeSeries(time_loop, :);                                  % (m^3/s); (horizontal vector: 1 X num_AdvecFluxes)
    current_RiverFlux                    = reshape(current_RiverFlux, 1, 1, num_AdvecFluxes);                   % (m^3/s); (vector-along-layers: 1 X 1 X num_AdvecFluxes)(m3/s per 1m BoxWidth); (m3/s per 1m BoxWidth);
    RiverFlux_repmat                     = repmat(current_RiverFlux, [num_boxes, num_boxes, 1]);                % (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes);            (m3/s per 1m BoxWidth); 
    SwitchResult                         = AdvcDirectionSwitch .* RiverFlux_repmat;                             % value is negative where flow direction is wrong @ t; (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    looky_negative                       = find(SwitchResult <= 0);                                             % find zero or backwards flow entries in matrix
    RiverFlux_repmat(looky_negative)     = 0;                                                                   % set fluxes in source box clms to 0; (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    RiverFlux_repmat                     = RiverFlux_repmat .* AdvectionSign;                                   % put correct sign on direction of flux (offshore is "+"); (m^3/s); (3D matrix: DestinationBox X SourceBox X num_AdvecFluxes)
    RiverFluxMatrix_temp                 = sum(RiverFlux_repmat, 3) * (60*60*24);                               % advection rate; (m^3/d); (2D matrix: DestinationBox X SourceBox)
                                                                                                                % sum all the individual advection fluxes into and out of each "destination" box
% % % %     RiverFluxMatrix_temp = RiverFluxMatrix_temp ./ repmat(current_BoxWidth', [1, num_boxes]);                   % QQQ (m3/d); scale by BoxWidth; (2D matrix: DestinationBox X SourceBox);;
    RiverFluxMatrix(time_loop, :, :)     = reshape(RiverFluxMatrix_temp', [1, num_boxes, num_boxes]);           % (m^3/d); (3D matrix: time X SourceBox X DestinationBox)
    
    
    % step 5d: identify upwelling vs downwelling events by source box ID --
    %          NOTE: there will only be ONE NorSea box receiving water from ocean (unless the rivers run backwards), but there may be TWO NorSea boxes giving water to the north
    AdvectionMatrix_temp                            = AdvectionMatrix_temp + RiverFluxMatrix_temp;  % this line is needed for NorSea case (not the other models); (m^3/d)
    Advection_DestinationSum                        = sum(AdvectionMatrix_temp, 2);                 % advected volume; (m^3/d); (vertical vector: DestinationBoxes X 1)
    Advection_DestinationSum(looky_RiverFluxBox)    = 0;                                            % this line is needed for NorSea case (not the other models)
    Advection_DestinationSum                        = round2(Advection_DestinationSum, 8);          % round off the very tiny error caused by spline fit
    Advection_DestinationSum                        = round2(Advection_DestinationSum, -3); % QQQ for NorSea, round roundoff error
    %   NOTE: all advection terms except those from external inputs (i.e. ocean) cancel out; 
    looky_ReceivingBox = find(Advection_DestinationSum < 0);
    if isempty(looky_ReceivingBox)
        OceanSourceBoxID(time_loop) = looky_OffshoreSurfaceBox;            % default to downwelling box if all advection = 0
    else
        OceanSourceBoxID(time_loop)  = find(Advection_DestinationSum < 0); % box number of box receiving advection from outside
    end
    
    
    % step 5e: vertical mixing --------------------------------------------
    current_VertMixing                   = VerticalMixing_TimeSeries(time_loop, :);                               % (m2/s); (horizontal vector: 1 X num_MixFluxes)
    current_VertMixing                   = reshape(current_VertMixing, 1, 1, num_MixFluxes);                      % (m2/s); (vector-along-layers: 1 X 1 X num_AdvecFluxes)
    VertMixing_repmat                    = repmat(current_VertMixing, [num_boxes, num_boxes, 1]);                 % (m2/s); (3D matrix: DestinationBox X SourceBox X num_MixFluxes)
    VertMixing_repmat                    = VertMixing_repmat .* VerticalMixingLink;                               % (m2/s); (3D matrix: DestinationBox X SourceBox X num_MixFluxes); (QQQ --> true??? put sign on direction of flux (sign here matters in ODE when multiplied against bottom_box - top_box)
    VerticalMixMatrix_temp               = sum(VertMixing_repmat, 3) * (60*60*24);                                % (m2/d); (2D matrix: DestinationBox X SourceBox)
    VerticalMixMatrix_temp               = VerticalMixMatrix_temp .* repmat(current_BoxWidth', [1, num_boxes]).* repmat(current_BoxLength', [1, num_boxes]);    % QQQ is this right???' scale by BoxHeight; (m3/d); (2D matrix: DestinationBox X SourceBox)
% % % %     VerticalMixMatrix_temp = VerticalMixMatrix_temp ./ repmat(current_BoxWidth', [1, num_boxes]);                   % QQQ (m3/d); scale by BoxWidth; (2D matrix: DestinationBox X SourceBox);;
    VerticalMixMatrix(time_loop, :, :)   = reshape(VerticalMixMatrix_temp', [1, num_boxes, num_boxes]);           % vertical mixing rate; (m3/d); (3D matrix: time X SourceBox X DestinationBox)
    
    
    % step 5f: horizontal mixing ------------------------------------------
    %           NOTE: no horizontal mixing in NorSea physical model
    
end

% step 5g: add advection terms (advection + river-driven advection)
NetAdvectionMatrix = AdvectionMatrix + RiverFluxMatrix;     % net advection rate (m^3/d); (3D matrix: time X SourceBox X DestinationBox (I II III IV V))





% *************************************************************************
% STEP 6: sinking fluxes to/from each box (identical for each t; t dimension not defined)
SinkLink                                = sum(SinkLink, 3);                % flatten SinkLink; (2D matrix: destination boxes X source boxes)
SinkLink_surface                        = zeros(num_boxes);
SinkLink_surface(:, looky_SurfaceBoxes) = SinkLink(:, looky_SurfaceBoxes); % only consider sinking from surface to sub-surface boxes
SinkLink_benthos                        = SinkLink;
SinkLink_benthos(:, looky_SurfaceBoxes) = 0;                               % only consider sinking from sub-surface to benthos (also includes surface to benthos mixed-boxes (Box I))





% *************************************************************************
% STEP 7: load nutrient data-----------------------------------------------
% step 7a: NorSea data
River_nox   = [439.7244074 421.3165891 449.1759071 343.4456117 228.89708 176.7776389 144.7625748 142.3211371 159.6738137 205.4506026 288.6058111 379.0991376]; % (mol/sec; 1 mol = 62 gramm, based on atomic weight of NO3)
box_I_NO3	= (River_nox ./ Qr(1, :)) * (1000); % (mmoles N/m3); (horizontal vector: 1 X 12)
box_II_NO3  = [7.29061983 7.37778799 7.637411379 3.215390226 1.397892228 0.478733668 0.76868936 0.475 0.877742105 1.2925 5.10566494 4.752117816];               % monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3)
box_III_NO3	= [7.513383725 7.590411587 7.798796083 4.981252523 4.302369645 2.569333396 4.483837439 1.663156022 2.178049716 3.96537328 6.389936759 6.619116311];	% monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3)
box_IV_NO3  = [7.29061983 7.37778799 7.637411379 3.215390226 1.397892228 0.478733668 0.76868936 0.475 0.877742105 1.2925 5.10566494 4.752117816];               % monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3)
box_V_NO3   = [7.513383725 7.590411587 7.798796083 4.981252523 4.302369645 2.569333396 4.483837439 1.663156022 2.178049716 3.96537328 6.389936759 6.619116311]; % monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3)
dat_NO3     = [box_I_NO3' box_II_NO3' box_III_NO3' box_IV_NO3' box_V_NO3'];     % monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3); (2D matrix: month X box; I, II, III, IV, V)

% step 7b: interpolate monthly means to daily values ----------------------
% allow for cyclical repeats over several years
build_NO3           = [];
for year_loop = 1:num_years
    build_NO3 = [build_NO3; dat_NO3];
end
NO3_doy       = interp1([1 build_midmonth_doy (365*num_years)]', [mean(dat_NO3([1 12], :)); build_NO3; mean(dat_NO3([1 12], :))], t_grid, 'spline'); % (2D matrix: num_t X num_AdvecFluxes); (m/s)
NO3_doy(NO3_doy < 0) = 0; % filter out negative NO3_doy values created during spline interpolation





% *************************************************************************
% STEP 8: WWT conversion terms---------------------------------------------
atomic_mass_N             = 14.00674;   % (g N / mole N)
atomic_mass_C             = 12.0107;    % (g C / mole C)

Chla_to_N_diatoms         = 2.19;       % (mg Chla mmoles N^-1) (Dickson & Wheeler 1995 L&O 40(3):533-543)
% Chla_to_N_diatoms         = 2.5;        % 2.49 to 2.67 (mg Chla mmoles N^-1) (Chan 1980 J Phycol 16:428-432)
Chla_to_N_dinoflagellates = 0.84;       % 0.73 to 0.95 (mg Chla mmoles N^-1) (Chan 1980 J Phycol 16:428-432)

% C_to_N_phytoplankton      = 7.3;        % general phytoplankton C:N (moles C / moles N) (Geider & LaRoche 2002 Eur. J. Phycol 37:1-17)
C_to_N_phytoplankton      = (106/16);   % Redfield ratio = C:N:P = 106:16:1 ---> C:N = 106:16 = 6.625 mole C/mole N
C_to_N_zooplankton        = 5;          % general zooplankton C:N (moles C moles N^-1) for mesozooplankton (W. Peterson pers com); C:N=5.16-5.26 [Schneider 1990 (Mar Biol 106:219-225)]; C:N=3.9 [Uye 1982]

WWT_to_C                  = 8.77;       % (g WWT / g C); (Steele et al. 2007), NOTE: I could not find this value in 2007 citation, must have gotten value directly from John, value is close to other lit. values; {Strickland, 1966 #1521} says "From the foregoing, it appears that the 10-12 mg algal weight:mg C is the most suitable factor for estimating phytoplankton biomass as ?wet weight?";
mgWWT_per_mmolesN         = (C_to_N_phytoplankton * atomic_mass_C * WWT_to_C); % (mg WWT/mmoles N)

mgram_to_gram             = 1000;       % (mg/g)
gram_to_ton               = 1000000;	% (g/t)
mgram_to_ton              = mgram_to_gram * gram_to_ton; % (mg/t)

W_to_microE               = 4.6;        % convert (W m^-2) to (microE m^-2 s^-1) at 400-700nm (Brock 1981 Ecol Model 14: 1-19)





% *************************************************************************
% STEP 9: light parameters-------------------------------------------------
LightParams.latitude        = latitude;   % latitude of NH line (decimal degress north) based on LTOP transects
LightParams.SolarConstant	= 1366;       % Solar const. (W m^-2) recent ave. (Froehlich & Lean (1998, Geographical Research Letters 25(23): 4377-4380))

LightParams.par_frac        = 0.43;       % fraction of 40 that is PAR, clear atmos. (Fasham, Ducklow, & McKelvie (1990, J. Mar. Res. 48:591-639), p. 604)
LightParams.surf_trans      = 0.85;       % 1-reflectance (Parsons, Takahachi, & Hargrave (1984, Biological Oceanographic Processes, 3rd ed.), p. 69)
LightParams.cloud_cover     = 0.50;       % fitting daily average and weekly-smoothed light model curve to weekly average of HMSC roof data by eye
% LightParams.cloud_cover     = 0.70;       % Ave. 1990-97, COADS Standard 1-deg. for 125.5W, 45.5N
LightParams.cloud_trans     = 1.0 - (0.7 * LightParams.cloud_cover);  % (Evans and Parslow (1985, Biol. Oceanogr. 3(3):327-347), p. 344)
LightParams.t_grid          = t_grid;

[SurfaceRadiation]          = f_LightIntensity(LightParams);
daily_average_light         = SurfaceRadiation.daily_average_light; % daily integrated solar raditation at ocean surface averaged across 24 hours (W m^-2 h^-1); (vertical vector: num_t X 1)
%                                                 NOTE: the daily average is also what was used by Spitz in her NPZD models
%                                                 NOTE: the daily integrated value avergaed over 24 hours is almost identical to the mean of the current instantaneous light intensity averaged over 24 hours (I checked)
current_light               = SurfaceRadiation.current_light; % surface solar raditation at current time (W/m2)
Kw                          = 0.067;	% Light attenuation_seawater (Newberger et al., 2003); (1/m)
Kp                          = 0.0095;   % Light attenuation_phytoplankton (Newberger et al., 2003); (m2/mmol N)





% *************************************************************************
% STEP 10: pack results for export-----------------------------------------
% step 10a: time dimensions -----------------------------------------------
ECOTRANphysics.datestart                   = datestart;                 % starting date
ECOTRANphysics.dateend                     = dateend;                   % ending date
ECOTRANphysics.t_grid                      = t_grid;
ECOTRANphysics.num_t                       = num_t;

% step 10b: space dimensions ----------------------------------------------
ECOTRANphysics.num_boxes                   = num_boxes;
ECOTRANphysics.BoxLength                   = BoxLength;                 % (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight_inshore           = BoxHeight_inshore;         % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight_offshore          = BoxHeight_offshore;        % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight                   = BoxHeight;                 % I, II, III, IV, V; mean box height; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxWidth                    = BoxWidth;                  % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxArea                     = BoxArea;                   % I, II, III, IV, V; (m2); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxVolume                   = BoxVolume;                 % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes)

% step 10c: box addresses -------------------------------------------------
ECOTRANphysics.looky_SubSurfaceBoxes       = looky_SubSurfaceBoxes;
ECOTRANphysics.looky_SurfaceBoxes          = looky_SurfaceBoxes;
ECOTRANphysics.looky_OffshoreSurfaceBox    = looky_OffshoreSurfaceBox;
ECOTRANphysics.looky_OffshoreSubSurfaceBox = looky_OffshoreSubSurfaceBox;
ECOTRANphysics.looky_RiverFluxBox          = looky_RiverFluxBox;        % Optional river alongshore input; Box 2 in CGoA model
ECOTRANphysics.OceanSourceBoxID            = OceanSourceBoxID;          % ocean sourcebox ID; (vertical vector: time X 1)

% step 10d: raw physical driver time-series -------------------------------
ECOTRANphysics.tau                         = tau;                       % Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (horizontal vector)
ECOTRANphysics.tau_doy                     = tau_doy;                   % Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (horizontal vector)
ECOTRANphysics.we                          = we;                        % vertical mixing rate, monthly mean: (m3/sec)
ECOTRANphysics.we_doy                      = we_doy;                    % vertical mixing rate, monthly mean: (m3/sec)
ECOTRANphysics.ue                          = ue;                        % horizontal mixing rate, monthly mean: (m3/s); (2d matrix: time X num_AdvecFluxes)
ECOTRANphysics.ue_doy                      = ue_doy;                    % horizontal mixing rate, monthly mean: (m3/s); (2d matrix: time X num_AdvecFluxes)

% step 10e: physical driver time-series -----------------------------------
ECOTRANphysics.AdvectionMatrix             = AdvectionMatrix;           % wind-driven advection rate = volume transported per day; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.RiverFluxMatrix             = RiverFluxMatrix;           % river-driven advection rate = volume transported per day; enters into Box II; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.VerticalMixMatrix           = VerticalMixMatrix;         % mixing rate = volume mixed per day; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.HorizontalMixMatrix         = HorizontalMixMatrix;       % mixing rate = volume mixed per day; (m3/d); (3D matrix: time X source box X destination box)

ECOTRANphysics.HorizontalMix_OffshoreSurface    = HorizontalMix_OffshoreSurface;    % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
ECOTRANphysics.HorizontalMix_OffshoreSubSurface = HorizontalMix_OffshoreSubSurface; % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)

ECOTRANphysics.NetAdvectionMatrix          = NetAdvectionMatrix;        % net advection rate (m3/d); (3D matrix:time X SourceBox X DestinationBox (I II III IV V))
ECOTRANphysics.BoxWashoutTime              = looky_WashoutTime;         % a list of days when one or more boxes would have been >100% washed out if advection cap not applied

% step 10f: misc info -----------------------------------------------------
ECOTRANphysics.SinkLink_surface            = SinkLink_surface;          % define sinking connections from surface to sub-surface boxes; (unitless); (2D matrix: destination boxes X source boxes)
ECOTRANphysics.SinkLink_benthos            = SinkLink_benthos;          % define sinking connections from sub-surface boxes to benthic detritus; (unitless); (2D matrix: destination boxes X source boxes)
ECOTRANphysics.num_AdvecFluxes             = num_AdvecFluxes;
ECOTRANphysics.num_MixFluxes               = num_MixFluxes;
ECOTRANphysics.num_HorizMixFluxes          = num_HorizMixFluxes;

% step 10g: nutrient time-series ------------------------------------------
ECOTRANphysics.dat_NO3                     = dat_NO3;                   % monthly mean NO3 + NO2; (mmole N/m3); (2D matrix: month X box; I, II, III, IV, V)
ECOTRANphysics.NO3_doy                     = NO3_doy;                   % daily NO3 + NO2 interpolated from monthly means; (mmole N/m3); (2D matrix: month X box; I, II, III, IV, V)

% step 10h: light model info ----------------------------------------------
ECOTRANphysics.MLD                         = MLD;                       % time-series of Mixed Layer Depth (for light intensity calculations, NOT advection calcs); (m); (vertical vector: length = time)
ECOTRANphysics.Io                          = daily_average_light;       % time-series of surface PAR light intensity; daily integrated solar raditation at ocean surface averaged across 24 hours; (W m^-2 h^-1) (Brock, 1981, R. Ozretich unpub. data);
ECOTRANphysics.Kw                          = Kw;                        % Light attenuation?seawater
ECOTRANphysics.Kp                          = Kp;                        % Light attenuation?phytoplankton (Newberger et al., 2003); (m2/mmol N)

% step 10i: conversion factors --------------------------------------------
ECOTRANphysics.atomic_mass_C               = atomic_mass_C;             % (g C / mole C)
ECOTRANphysics.atomic_mass_N               = atomic_mass_N;             % (g N / mole N)
ECOTRANphysics.C_to_N_phytoplankton        = C_to_N_phytoplankton;      % Redfield ratio = C:N:P = 106:16:1 ---> C:N = 106:16 = 6.625 mole C/mole N
ECOTRANphysics.C_to_N_zooplankton          = C_to_N_zooplankton;        % general zooplankton C:N (moles C moles N^-1) for mesozooplankton (W. Peterson pers com); C:N=5.16-5.26 [Schneider 1990 (Mar Biol 106:219-225)]; C:N=3.9 [Uye 1982]
ECOTRANphysics.Chla_to_N_diatoms           = Chla_to_N_diatoms;         % (mg Chla mmoles N^-1) (Dickson & Wheeler 1995 L&O 40(3):533-543)
ECOTRANphysics.Chla_to_N_dinoflagellates   = Chla_to_N_dinoflagellates;
ECOTRANphysics.mgWWT_per_mmolesN           = mgWWT_per_mmolesN;         % (mg WWT/mmoles N); for phytoplankton
ECOTRANphysics.WWT_to_C                    = WWT_to_C;                  % (g WWT / g C); (Steele et al. 2007); QQQ recheck this for phytoplankton


% end m-file***************************************************************