function [ECOTRANphysics] = f_ECOTRANphysics_upwelling_08022018(PHYSICSinput)
% returns Advection and Mixing exchanges between boxes
% use for NCC upwelling setting
% takes:
%       internally defined time-series of advection & mixing rates
% returns ECOTRANphysics:
%       AdvectionMatrix         advection rate = volume transported per day; (m3/d)
%                               (3D matrix: time X  source box X destination box)
%                               (values can be positive or negative)
%       VerticalMixMatrix       vertical mixing rate = volume mixed per day; (m3/d)
%                               (3D matrix: time X  source box X destination box)
%                               (values can be positive or negative; sign defines direction of net mixing)
% calls:
%       round2                  (round to a specified number of decimal places)
%       calcur_res.mat          (dataset with monthly mean salinity, temperature, and NO3+NO2 data)
%       f_LightIntensity
% NOTE: What happens in cases when there is a complete advective washout of a spatial box?)
%       I added cap to advection rate to prevent >100% box washout (but do not account for river flux)
%       Added warning for days when AdvectionMatrix > BoxVolume; see ECOTRANphysics.BoxWashoutTime
% revision date: 8-2-2018


% *************************************************************************
% STEP 1: basic domain parameters (NCC upwelling)--------------------------
% step 1a: physical parameters --------------------------------------------
latitude     = 44.6516667;              % latitude of NH line (decimal degress north) based on LTOP transects
rho_water    = 1000;                    % seawater density; (kg/m3)
rho_air      = 1.220;                   % air density (kg/m3) (Schwing et al. 1996)
coriollis    = 1.025 * 10^(-4);         % coriollis factor (1/s); (NH-Line NNPPZD model: Ruzicka et al. 2011)
midmonth_doy = [15 45 74 105 135 166 196 227 258 288 319 349]; % mid-month day-of-year

% step 1b: time domain and vectors ----------------------------------------
datestart    = PHYSICSinput.datestart;  % enter starting date
dateend      = PHYSICSinput.dateend;    % enter ending date
dt           = PHYSICSinput.dt;         % t-step (d)
t_grid       = PHYSICSinput.t_grid;     % t_grid; (vertical vector)
num_t        = length(t_grid);          % length of t_grid; (scaler)
min_t        = min(t_grid);
max_t        = max(t_grid);
num_years    = ceil(max_t/365);

% step 1c: Box ID info ----------------------------------------------------
num_boxes                   = 5;        % I, II, III, IV, V
num_AdvecFluxes             = 6;        % advective fluxes: A_12, A_13, A_24, A_35, A_4offshore, A_5offshore
num_MixFluxes               = 2;        % vertical mix fluxes: w_23, w_45
num_HorizMixFluxes          = 6;        % horizontal mix fluxes: u_12 u_13 u_24 u_35 u_4ocean u_5ocean
looky_SubSurfaceBoxes       = [3, 5];
looky_SurfaceBoxes          = [2, 4];
looky_OffshoreSurfaceBox    = 4;
looky_OffshoreSubSurfaceBox = 5;
looky_RiverFluxBox          = 2;        % River input from alongshore; (Box 2 in CGoA downwelling model)

% step 1d: spatial dimensions ---------------------------------------------
%          NOTE: Mixed Layer Depth (only used for light intensity calculations, not used for advection rate calculations)
%          NOTE: box geometry with slanty bottom
maxMLD                      = 15;                                                       % max MLD; (m) % alt 40
minMLD                      = 15;                                                       % min MLD; (m) % alt 10
rangeMLD                    = maxMLD - minMLD;                                          % set minimum mixed layer depth and annual range of the mixed layer depth; (m)
MLD                         = (cos(((t_grid/365)*pi)*2) * (rangeMLD * 0.5) + (minMLD + rangeMLD * 0.5)); % MLD; (m); (vertical vector: time X 1)
BoxLength                   = [10000, 20000, 20000, 20000, 20000];                      % (m); I, II, III, IV, V
BoxLength                   = repmat(BoxLength, [num_t, 1]);                            % (m); (2D matrix: time X num_boxes)
BoxWidth                    = [1, 1, 1, 1, 1];                                          % (m); I, II, III, IV, V
BoxWidth                    = repmat(BoxWidth, [num_t, 1]);                             % (m); (2D matrix: time X num_boxes)
BoxHeight_inshore           = [repmat(0,  [num_t, 1]), MLD, (30-MLD),  MLD, (140-MLD)]; % (m); (2D matrix: time X num_boxes); I, II, III, IV, V
BoxHeight_offshore          = [repmat(30, [num_t, 1]), MLD, (140-MLD), MLD, (250-MLD)]; % (m); (2D matrix: time X num_boxes); I, II, III, IV, V
BoxHeight                   = 0.5 * (BoxHeight_inshore + BoxHeight_offshore);           % mean box height; (m); (2D matrix: time X num_boxes); I, II, III, IV, V
BoxArea                     = BoxHeight .* BoxLength;                                   % (m2); (2D matrix: time X num_boxes); I, II, III, IV, V
BoxVolume                   = BoxArea .* BoxWidth;                                      % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes);





% *************************************************************************
% STEP 2: prepare advection & mixing parameters----------------------------
% step 2a: Brink Physics raw values (NCC upwelling) -----------------------
%          NOTE: monthly means
%          NOTE: ONshore direction is positive

% wind-driven advection (Qw) ..............................................
%       Qw = tau .* (1/coriollis) .* (1/rho_water) = daily advective flux rate; (m3/s per 1m BoxWidth)
%       Alongshore wind stress (tau) monthly mean: (N/m^2) = (kg*m/m2/s2) = (kg/m/s2)
tau = [0.0680748069736075, 0.0433269605437942, 0.0448631025587659, 0.0176074709095014, -0.0105705908497718, -0.0202353968838113, -0.0298904158691320, -0.0193376707154904, -0.0124022877853344, 0.0219368906632379, 0.0642634881319758, 0.0709770739741683];
% Qw  = tau_doy .* (1/coriollis) .* (1/1000) * (-1); % daily advective flux rate; (m3/s per 1m BoxWidth); (vertical vector); (NOTE: change of sign to make offshore "POSITIVE")

% river infux (Qr) ........................................................
%       (m3/s per 1m BoxWidth)
%       NOTE: all 0 for NCC; FFF may add CR influence in future
Qr = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];

% vertical mixing rate ....................................................
%       (m/s)
%       NOTE: no direction, so all we are positive
we  = [2.09051350944941e-05, 1.70040101641047e-05, 1.15783391649564e-05, 4.45890782591914e-06, 1.60603701399058e-06, 1.20405100592767e-06, 1.61576927579862e-06, 1.51120326652934e-06, 2.07979462147540e-06, 4.74448045109569e-06, 1.40606441256106e-05, 2.13712842043411e-05];

% horizontal mixing rate ..................................................
%       (m/s)
%       NOTE: not considered for NCC, so all are 0
ue = [
    0 0 0 0 0 0 0 0 0 0 0 0     % u_12
    0 0 0 0 0 0 0 0 0 0 0 0     % u_13
    0 0 0 0 0 0 0 0 0 0 0 0     % u_24
    0 0 0 0 0 0 0 0 0 0 0 0     % u_35
    0 0 0 0 0 0 0 0 0 0 0 0     % u_4ocean
    0 0 0 0 0 0 0 0 0 0 0 0];   % u_5ocean

% step 2b: allow for cyclical repeats over several years ------------------
build_midmonth_doy = [];
build_tau          = [];
% build_Qw           = [];
build_Qr           = [];
build_we           = [];
build_ue           = [];
for year_loop = 1:num_years
    build_midmonth_doy = [build_midmonth_doy (midmonth_doy + (365 * (year_loop - 1)))];  % (horizontal vector: 1 X (12*years)
    build_tau          = [build_tau tau];  % (horizontal vector: 1 X (12*years))
%     build_Qw           = [build_Qw Qw];
    build_Qr           = [build_Qr Qr];  % (horizontal vector: 1 X (12*years))
    build_we           = [build_we we];  % (horizontal vector: 1 X (12*years))
    build_ue           = [build_ue ue];  % (2D matrix: num_HorizMixFluxes X (12*years))
end % (year_loop)

% step 2b: interpolate monthly means to daily values ----------------------
tau_doy      = interp1([1 build_midmonth_doy (365*num_years)], [mean(tau([1 12])) build_tau mean(tau([1 12]))], t_grid, 'spline');	% (kg/m/s2); (vertical vector: num_t X 1)
% Qw_doy       = interp1([1 build_midmonth_doy (365*num_years)], [mean(Qw([1 12])) build_Qw mean(Qw([1 12]))], t_grid, 'spline');     % (m3/s per 1m BoxWidth); (vertical vector: num_t X 1)
Qr_doy       = interp1([1 build_midmonth_doy (365*num_years)], [mean(Qr([1 12])) build_Qr mean(Qr([1 12]))], t_grid, 'spline');     % (m3/s per 1m BoxWidth); (vertical vector: num_t X 1)
we_doy       = interp1([1 build_midmonth_doy (365*num_years)], [mean(we([1 12])) build_we mean(we([1 12]))], t_grid, 'spline');     % (m/s); (vertical vector: num_t X 1)
% we_doy       = we_doy / 2; % NOTE: division by 1/2 already accounted for in original calculation of rates; vertical mixing extends 1/2 into top box & 1/2 into bottom box; (m/s); (vertical vector length num_t)
ue_doy       = interp1([1 build_midmonth_doy (365*num_years)]', [mean(ue(:, [1 12]), 2) build_ue mean(ue(:, [1 12]), 2)]', t_grid', 'spline'); % (m/s); (2D matrix: num_t X num_HorizMixFluxes)

Qr_doy(Qr_doy < 0) = 0; % filter out negative ue values created during spline interpolation
ue_doy(ue_doy < 0) = 0; % filter out negative ue values created during spline interpolation





% *************************************************************************
% STEP 3: calculate upwelling rates ---------------------------------------
% step 3a: wind-stress driver ---------------------------------------------
BUI_Brink       = tau_doy .* (1/coriollis) .* (1/1000) * (-1);  % daily advective flux rate; (m3/s per 1m BoxWidth); (vertical vector: num_t X 1); (NOTE: change of sign to make offshore "POSITIVE")

% step 3e: select upwelling driver ----------------------------------------
AdvecFluxRate	= BUI_Brink; display('wind stress physics');	% (m3/s per 1m of BoxWidth); (vertical vector); positive is upwelling, negative is downwelling
RiverFluxRate 	= Qr_doy;                                       % (m3/s per 1m BoxWidth); (vertical vector: num_t X 1)





% *************************************************************************
% STEP 4: put a limit on AdvecFluxRate and RiverFluxRate-------------------
%         prevent total washout of small boxes on extreme days
%         NOTE: still possible to have box washed out if RiverFluxRate tips the balance
max_AdvecFluxRate                   = min((BoxVolume * 1/(60*60*24)), [], 2); % max absolute advection rate (m3/s) = one BoxVolume per day; (vertical vector)
looky_WashoutTime                   = find(abs(AdvecFluxRate) > max_AdvecFluxRate);
AdvecFluxRate(looky_WashoutTime)    = sign(AdvecFluxRate(looky_WashoutTime)) .* max_AdvecFluxRate(looky_WashoutTime);
looky_WashoutTime                   = find(abs(RiverFluxRate) > max_AdvecFluxRate);
RiverFluxRate(looky_WashoutTime)    = sign(RiverFluxRate(looky_WashoutTime)) .* max_AdvecFluxRate(looky_WashoutTime);





% *************************************************************************
% STEP 5: define Advective fluxes and River fluxes to use for TimeSeries---
% step 5a: advection ------------------------------------------------------
%          NOTE: onshore is POSITIVE, offshore is NEGATIVE
Advection_TimeSeries        = repmat(AdvecFluxRate, [1, 6]) .* repmat([(-1) (1) (-1) (1) (-1) (1)], [num_t, 1]); % (m3/s per 1m BoxWidth); (2D matrix: time X num_AdvecFluxes: A_12 A_13 A_24 A_35 A_4ocean A_5ocean
RiverFlux_TimeSeries        = repmat(RiverFluxRate, [1, 6]) .* repmat([(0)  (0) (-1) (0) (-1) (0)], [num_t, 1]); % (m3/s per 1m BoxWidth); (2D matrix: time X num_AdvecFluxes: A_12 A_13 A_24 A_35 A_4ocean A_5ocean

% step 5b: mixing ---------------------------------------------------------
VerticalMixing_TimeSeries   = repmat(we_doy, [1, 2])        .* repmat([1 1], [num_t, 1]); % (m/s); (2D matrix: time X num_MixFluxes) w_23, w_45
%          NOTE: all POSITIVE & already divided 1/2 upward and 1/2 downward
%          NOTE: the second term (repmat([1 1], [num_t, 1])) is not necessary
HorizontalMixing_TimeSeries = ue_doy; % (m3/s per 1m BoxWidth); (2D matrix: time X num_HorizMixFluxes) u_12 u_13 u_24 u_35 u_4ocean u_5ocean





% *************************************************************************
% STEP 6: Physical Structure (NCC upwelling)-------------------------------
% step 6a: define advective connections between boxes (3D matrix: destination boxes X source boxes X specific advection flux)
%          NOTE: the sign is used to identify source box depending on onshore-vs-offshore flux
AdvcDirectionSwitch(1:5, 1:5, 1) = [
-1	1	0	0	0
-1	1	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % A_12 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 2) = [
-1	0	1	0	0
0	0	0	0	0
-1	0	1	0	0
0	0	0	0	0
0	0	0	0	0]; % A_13 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 3) = [
0	0	0	0	0
0	-1	0	1	0
0	0	0	0	0
0	-1	0	1	0
0	0	0	0	0]; % A_24 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	-1	0	1
0	0	0	0	0
0	0	-1	0	1]; % A_35 (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	-1	0
0	0	0	0	0]; % A_4ocean (matrix: spatial cell X spatial cell: I II III IV V)

AdvcDirectionSwitch(1:5, 1:5, 6) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	-1]; % A_5ocean (matrix: spatial cell X spatial cell: I II III IV V)


% step 6b: assign proper sign to advective flux (3D matrix: destination boxes X source boxes X specific advection flux)
%          NOTE: AdvectionSign refers to whether a flux is a gain or a loss to a box, it does not refer to a onshore/offshore direction
AdvectionSign(1:5, 1:5, 1) = [
1	1	0	0	0
-1	-1	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % A_12 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 2) = [
1	0	1	0	0
0	0	0	0	0
-1	0	-1	0	0
0	0	0	0	0
0	0	0	0	0]; % A_13 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 3) = [
0	0	0	0	0
0	1	0	1	0
0	0	0	0	0
0	-1	0	-1	0
0	0	0	0	0]; % A_24 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	1	0	1
0	0	0	0	0
0	0	-1	0	-1]; % A_35 (matrix: spatial cell X spatial cell: I II III IV V)

AdvectionSign(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	1	0
0	0	0	0	0]; % A_4ocean (matrix: spatial cell X spatial cell: I II III IV V); (produces offshore loss to ocean)

AdvectionSign(1:5, 1:5, 6) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	1]; % A_5ocean (matrix: spatial cell X spatial cell: I II III IV V); (produces offshore loss to ocean)


% step 6c: define vertical mixing connections between boxes (3D matrix: DestinationBoxes X SourceSoxes X mixing flux)
VerticalMixingLink(1:5, 1:5, 1) = [
0	0	0	0	0
0	0	1	0	0
0	1	0	0	0
0	0	0	0	0
0	0	0	0	0]; % w_23

VerticalMixingLink(1:5, 1:5, 2) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	1
0	0	0	1	0]; % w_45


% step 6d: define horizontal mixing connections between boxes (3D matrix: DestinationBoxes X SourceSoxes X mixing flux)
HorizontalMixingLink(1:5, 1:5, 1) = [
0	1	0	0	0
1	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % u_12 (matrix: spatial cell X spatial cell: I II III IV V)

HorizontalMixingLink(1:5, 1:5, 2) = [
0	0	1	0	0
0	0	0	0	0
1	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % u_13 (matrix: spatial cell X spatial cell: I II III IV V)

HorizontalMixingLink(1:5, 1:5, 3) = [
0	0	0	0	0
0	0	0	1	0
0	0	0	0	0
0	1	0	0	0
0	0	0	0	0]; % u_24 (matrix: spatial cell X spatial cell: I II III IV V)

HorizontalMixingLink(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	1
0	0	0	0	0
0	0	1	0	0]; % u_35 (matrix: spatial cell X spatial cell: I II III IV V)

HorizontalMixingLink(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % u_4ocean (matrix: spatial cell X spatial cell: I II III IV V); NOTE: this does NOT define link between box 4 and ocean

HorizontalMixingLink(1:5, 1:5, 6) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % u_5ocean (matrix: spatial cell X spatial cell: I II III IV V); NOTE: this does NOT define link between box 5 and ocean


% step 6e: mixing face areas for horizontal mixing fluxes (u_12 u_13 u_24 u_35 u_4ocean u_5ocean)
BoxMixingFace = [BoxHeight_inshore(:, 2) BoxHeight_inshore(:, 3) BoxHeight_inshore(:, 4) BoxHeight_inshore(:, 5) BoxHeight_offshore(:, 4) BoxHeight_offshore(:, 5)] .* repmat(BoxWidth(:, 1), [1, num_HorizMixFluxes]); % (m2); (2D matrix: time X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean

% step 6f: define sinking connections between boxes (3D matrix: DestinationBoxes X SourceSoxes X sinking flux)
SinkLink(1:5, 1:5, 1) = [
-1	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0]; % S_1benthos

SinkLink(1:5, 1:5, 2) = [
0	0	0	0	0
0	-1	0	0	0
0	1	0	0	0
0	0	0	0	0
0	0	0	0	0]; % S_23

SinkLink(1:5, 1:5, 3) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	-1	0
0	0	0	1	0]; % S_45

SinkLink(1:5, 1:5, 4) = [
0	0	0	0	0
0	0	0	0	0
0	0	-1	0	0
0	0	0	0	0
0	0	0	0	0]; % S_3benthos

SinkLink(1:5, 1:5, 5) = [
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	0
0	0	0	0	-1]; % S_5benthos





% *************************************************************************
% STEP 7: net advection & mixing gains/losses to/from each box for each t--
AdvectionMatrix                  = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
RiverFluxMatrix                  = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
VerticalMixMatrix                = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
HorizontalMixMatrix              = zeros(num_t, num_boxes, num_boxes); % initialize; (3D matrix: time X source X destination (I II III IV V))
HorizontalMix_OffshoreSurface    = zeros(num_t, 1);                    % initialize; (vertical vector: time X 1); u_4ocean
HorizontalMix_OffshoreSubSurface = zeros(num_t, 1);                    % initialize; (vertical vector: time X 1); u_5ocean
OceanSourceBoxID                 = zeros(num_t, 1);                    % initialize; (vertical vector)

for time_loop = 1:num_t % FFF can vectorize all this in future to speed things up
    
    current_BoxWidth                     = BoxWidth(time_loop, :);      % (m);  (horizontal vector: 1 X num_boxes)
    current_BoxLength                    = BoxLength(time_loop, :);     % (m);  (horizontal vector: 1 X num_boxes)
    current_BoxMixingFace                = BoxMixingFace(time_loop, :); % (m2); (horizontal vector: 1 X num_HorizMixFluxes)

    % step 7b: advection --------------------------------------------------
    current_advection                    = Advection_TimeSeries(time_loop, :);                          % (m3/s per 1m BoxWidth); (horizontal vector: 1 X num_AdvecFluxes)
    current_advection                    = reshape(current_advection, 1, 1, num_AdvecFluxes);           % (m3/s per 1m BoxWidth); (vector-along-layers: 1 X 1 X num_AdvecFluxes)
    advection_repmat                     = repmat(current_advection, [num_boxes, num_boxes, 1]);        % (m3/s per 1m BoxWidth); (3D matrix:  destination box X source box X num_AdvecFluxes)
    SwitchResult                         = AdvcDirectionSwitch .* advection_repmat;                     % (m3/s per 1m BoxWidth); value is negative where flow direction is wrong @ t; (3D matrix: destination box X source box X num_AdvecFluxes)
    looky_negative                       = find(SwitchResult <= 0);                                     % find zero or backwards flow entries in matrix
    advection_repmat(looky_negative)     = 0;                                                           % set fluxes in source box clms to 0; (m3/s per 1m BoxWidth); (3D matrix:  destination box X source box X num_AdvecFluxes)
    advection_repmat                     = advection_repmat .* AdvectionSign;                           % put correct sign on direction of flux (offshore is "+"); (m3/s per 1m BoxWidth); (3D matrix: destination box X source box X num_AdvecFluxes)
    AdvectionMatrix_temp                 = sum(advection_repmat, 3) * (60*60*24);                       % advection rate (m3/d per 1m BoxWidth); (2D matrix: destination boxes X source boxes)
                                                                                                        % sum all the individual advection fluxes into and out of each "destination" box,
    AdvectionMatrix_temp                 = AdvectionMatrix_temp  .* repmat(current_BoxWidth', [1, num_boxes]); % (m3/d); scale by BoxWidth; (2D matrix: DestinationBox X SourceBox); this is just a formality unless BoxWdith is not 1 m
    AdvectionMatrix(time_loop, :, :)     = reshape(AdvectionMatrix_temp', [1, num_boxes, num_boxes]);   % advection rate (m3/d); (3D matrix:time X SourceBox X DestinationBox (I II III IV V))
    
    % step 7c: identify upwelling vs downwelling events by source box ID --
    Advection_DestinationSum             = sum(AdvectionMatrix_temp, 2);                                % advected volume (m3/d); (3D matrix: 1 X 1 X DestinationBoxes)
    Advection_DestinationSum             = round2(Advection_DestinationSum, 8);                         % round off the very tiny error caused by spline fit
    %   NOTE: all advection terms except those from external inputs (i.e. ocean or river) cancel out; 
    looky_ReceivingBox = find(Advection_DestinationSum < 0);
    if isempty(looky_ReceivingBox)
        OceanSourceBoxID(time_loop) = looky_OffshoreSurfaceBox;            % default to downwelling box if all advection = 0
    else
        OceanSourceBoxID(time_loop)  = find(Advection_DestinationSum < 0); % box number of box receiving advection from outside
    end
    
    % step 7c: riverine advection -----------------------------------------
    current_RiverFlux                    = RiverFlux_TimeSeries(time_loop, :);                                  % (m3/s per 1m BoxWidth); (horizontal vector: 1 X num_AdvecFluxes)
    current_RiverFlux                    = reshape(current_RiverFlux, 1, 1, num_AdvecFluxes);                   % (m3/s per 1m BoxWidth); (vector-along-layers: 1 X 1 X num_AdvecFluxes)
    RiverFlux_repmat                     = repmat(current_RiverFlux, [num_boxes, num_boxes, 1]);                % (m3/s per 1m BoxWidth); (3D matrix:  destination box X source box X num_AdvecFluxes)
    SwitchResult                         = AdvcDirectionSwitch .* RiverFlux_repmat;                             % (m3/s per 1m BoxWidth); value is negative where flow direction is wrong @ t; (3D matrix: destination box X source box X num_AdvecFluxes)
    looky_negative                       = find(SwitchResult <= 0);                                             % find zero or backwards flow entries in matrix
    RiverFlux_repmat(looky_negative)     = 0;                                                                   % set fluxes in source box clms to 0; (m3/s per 1m BoxWidth); (3D matrix:  destination box X source box X num_AdvecFluxes)
    RiverFlux_repmat                     = RiverFlux_repmat .* AdvectionSign;                                   % put correct sign on direction of flux (offshore is "+"); (m3/s per 1m BoxWidth); (3D matrix: destination box X source box X num_AdvecFluxes)
    RiverFluxMatrix_temp                 = sum(RiverFlux_repmat, 3) * (60*60*24);                               % advection rate (m3/d per 1m BoxWidth); (2D matrix: destination boxes X source boxes)
                                                                                                                % sum all the individual advection fluxes into and out of each "destination" box,
    RiverFluxMatrix_temp                 = RiverFluxMatrix_temp  .* repmat(current_BoxWidth', [1, num_boxes]);  % scale by BoxWidth;      (2D matrix: DestinationBox X SourceBox);                              (m3/d); this is just a formality unless BoxWdith is not 1 m
    RiverFluxMatrix(time_loop, :, :)     = reshape(RiverFluxMatrix_temp', [1, num_boxes, num_boxes]);           % advection rate (m3/d); (3D matrix:time X SourceBox X DestinationBox (I II III IV V))
    
    % step 7d: vertical mixing --------------------------------------------
    current_VertMixing                   = VerticalMixing_TimeSeries(time_loop, :);                         % (m/s); (horizontal vector: 1 X num_MixFluxes)
    current_VertMixing                   = reshape(current_VertMixing, 1, 1, num_MixFluxes);                % (m/s); (vector-along-layers: 1 X 1 X num_AdvecFluxes)
    VertMixing_repmat                    = repmat(current_VertMixing, [num_boxes, num_boxes, 1]);           % (m/s); (3D matrix: num_boxes X num_boxes X num_MixFluxes)
    VertMixing_repmat                    = VertMixing_repmat .* VerticalMixingLink;                         % put sign on direction of flux (sign here matters in ODE when multiplied against bottom_box - top_box); (m/s); (3D matrix: num_boxes X num_boxes X num_MixFluxes)
    VerticalMixMatrix_temp               = sum(VertMixing_repmat, 3) * (60*60*24);                          % vertical mixing rate (m/d); (2D matrix: destination boxes X source boxes)
    VerticalMixMatrix_temp               = VerticalMixMatrix_temp .* repmat((current_BoxLength .* current_BoxWidth)', [1, num_boxes]); % scale by box size (horizontal area); mixing rate (m3/d); (2D matrix: DestinationBoxes X SourceBoxes)
    VerticalMixMatrix(time_loop, :, :)   = reshape(VerticalMixMatrix_temp', [1, num_boxes, num_boxes]);     % mixing rate (m3/d); (3D matrix: time X SourceBox X DestinationBox (I II III IV V))

    % step 7e: horizontal mixing ------------------------------------------
    current_HorizMixing                         = HorizontalMixing_TimeSeries(time_loop, :);                % (m/s); (horizontal vector: 1 X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    current_HorizMixing                         = current_HorizMixing * (60*60*24);                         % (m/d); (horizontal vector: 1 X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    current_HorizMixing                         = current_HorizMixing .* current_BoxMixingFace;             % (m3/d); (horizontal vector: 1 X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    current_HorizMixing                         = reshape(current_HorizMixing, 1, 1, num_HorizMixFluxes);   % (m3/d); (vector-along-layers: 1 X 1 X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    HorizMixing_repmat                          = repmat(current_HorizMixing, [num_boxes, num_boxes, 1]);   % (m3/d); (3D matrix: DestinationBox X SourceBox X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    HorizMixing_repmat                          = HorizMixing_repmat .* HorizontalMixingLink;               % (m3/d); (3D matrix: DestinationBox X SourceBox X num_HorizMixFluxes); u_12 u_13 u_24 u_35 u_4ocean u_5ocean
    HorizMixing_repmat                          = sum(HorizMixing_repmat, 3);                               % (m3/d); (2D matrix: DestinationBox X SourceBox);
    HorizontalMixMatrix(time_loop, :, :)        = reshape(HorizMixing_repmat', [1, num_boxes, num_boxes]);  % horizontal mixing rate; (m3/d); (3D matrix: time X SourceBox X DestinationBox);
    HorizontalMix_OffshoreSurface(time_loop)    = current_HorizMixing(1, 1, 5);                             % horizontal mixing rate u_4ocean; (m3/d); (vertical vector: time X 1)
    HorizontalMix_OffshoreSubSurface(time_loop) = current_HorizMixing(1, 1, 6);                             % horizontal mixing rate u_5ocean; (m3/d); (vertical vector: time X 1)
    
end

% step 7f: add advection terms (wind-drive advection + river-driven advection)
NetAdvectionMatrix = AdvectionMatrix + RiverFluxMatrix; % net advection rate (m3/d); (3D matrix: time X SourceBox X DestinationBox (I II III IV V))





% *************************************************************************
% STEP 8: sinking fluxes to/from each box (identical for each t; t dimension not defined)
SinkLink                                = sum(SinkLink, 3);                 % flatten SinkLink; (2D matrix: destination boxes X source boxes)
SinkLink_surface                        = zeros(num_boxes);
SinkLink_surface(:, looky_SurfaceBoxes) = SinkLink(:, looky_SurfaceBoxes);  % only consider sinking from surface to sub-surface boxes
SinkLink_benthos                        = SinkLink;
SinkLink_benthos(:, looky_SurfaceBoxes) = 0;                                % only consider sinking from sub-surface to benthos (also includes surface to benthos mixed-boxes (Box I))





% *************************************************************************
% STEP 9: load nutrient data (NCC)-----------------------------------------
%         The file calcur_res.mat contains the structure "calcur" with the fields
%         "model_box", "var", and "monthly_mean". To keep usage (i.e., searching)
%         simple, model_box and var use a numeric code:
% 
%           model_box:
%               1: coastal box: everything shoreward of the 60m isobath
%               2: shelf mixed layer (ML) box: the upper 15m between the 60m and 200m isobath
%               3: shelf deep box: 15m to the bottom, between the 60m and 200m isobath
%               4: shelf break ML box: the upper 15m in a 20km swatch offshore of the 200m isobath
%               5: shelf break deep box: 15m to the bottom in a 20km swatch offshore of the 200m isobath
% 
%           var:
%               1: salinity
%               2: temperature
%               3: NO3+NO2
% 
%       The field "monthly_mean" contains 12 values with the monthly means.
%       The structure "calcur" has 15 entries: one for each model box and variable.
% step 9a: load "calcur" --------------------------------------------------
NutrientFile_directory     = '/Users/ruzickaj/Documents/ECOTRAN_08052018/ECOTRAN_code/Physics_code/';
readNutrientFile           = 'calcur_res.mat'; % monthly mean nutrients
readNutrientFile           = [NutrientFile_directory readNutrientFile];
load(readNutrientFile, 'calcur')
looky_NO3                   = find([calcur.model_box]==1 & [calcur.var] == 3);
box_I_NO3                   = calcur(looky_NO3).monthly_mean;
looky_NO3                   = find([calcur.model_box]==2 & [calcur.var] == 3);
box_II_NO3                  = calcur(looky_NO3).monthly_mean;
looky_NO3                   = find([calcur.model_box]==3 & [calcur.var] == 3);
box_III_NO3                 = calcur(looky_NO3).monthly_mean;
looky_NO3                   = find([calcur.model_box]==4 & [calcur.var] == 3);
box_IV_NO3                  = calcur(looky_NO3).monthly_mean;
looky_NO3                   = find([calcur.model_box]==5 & [calcur.var] == 3);
box_V_NO3                   = calcur(looky_NO3).monthly_mean;

dat_NO3                     = [box_I_NO3' box_II_NO3' box_III_NO3' box_IV_NO3' box_V_NO3']; % monthly mean NO3 + NO2; (micro-moles N/L) = (mmoles N/m3); (matrix: month X box; I, II, III, IV, V)

% step 9b: interpolate monthly means to daily values ----------------------
%          allow for cyclical repeats over several years
build_NO3           = [];
for year_loop = 1:num_years
    build_NO3 = [build_NO3; dat_NO3];
end
NO3_doy       = interp1([1 build_midmonth_doy (365*num_years)]', [mean(dat_NO3([1 12], :)); build_NO3; mean(dat_NO3([1 12], :))], t_grid, 'spline'); % (2D matrix: num_t X num_AdvecFluxes); (m/s)
NO3_doy(NO3_doy < 0) = 0; % filter out negative NO3_doy values created during spline interpolation





% *************************************************************************
% STEP 10: WWT conversion terms--------------------------------------------
atomic_mass_N             = 14.00674;   % (g N / mole N)
atomic_mass_C             = 12.0107;    % (g C / mole C)

Chla_to_N_diatoms         = 2.19;       % (mg Chla mmoles N^-1) (Dickson & Wheeler 1995 L&O 40(3):533-543)
% Chla_to_N_diatoms         = 2.5;        % 2.49 to 2.67 (mg Chla mmoles N^-1) (Chan 1980 J Phycol 16:428-432)
Chla_to_N_dinoflagellates = 0.84;       % 0.73 to 0.95 (mg Chla mmoles N^-1) (Chan 1980 J Phycol 16:428-432)

% C_to_N_phytoplankton      = 7.3;        % general phytoplankton C:N (moles C / moles N) (Geider & LaRoche 2002 Eur. J. Phycol 37:1-17)
C_to_N_phytoplankton      = (106/16);   % Redfield ratio = C:N:P = 106:16:1 ---> C:N = 106:16 = 6.625 mole C/mole N
C_to_N_zooplankton        = 5;          % general zooplankton C:N (moles C moles N^-1) for mesozooplankton (W. Peterson pers com); C:N=5.16-5.26 [Schneider 1990 (Mar Biol 106:219-225)]; C:N=3.9 [Uye 1982]

WWT_to_C                  = 8.77;       % (g WWT / g C); (Steele et al. 2007), NOTE: I could not find this value in 2007 citation, must have gotten value directly from John, value is close to other lit. values; {Strickland, 1966 #1521} says "From the foregoing, it appears that the 10-12 mg algal weight:mg C is the most suitable factor for estimating phytoplankton biomass as ?wet weight?";
mgWWT_per_mmolesN         = (C_to_N_phytoplankton * atomic_mass_C * WWT_to_C); % (mg WWT/mmoles N)

mgram_to_gram             = 1000;       % (mg/g)
gram_to_ton               = 1000000;	% (g/t)
mgram_to_ton              = mgram_to_gram * gram_to_ton; % (mg/t)

W_to_microE               = 4.6;        % convert (W m^-2) to (microE m^-2 s^-1) at 400-700nm (Brock 1981 Ecol Model 14: 1-19)





% *************************************************************************
% STEP 11: light parameters------------------------------------------------
LightParams.latitude        = latitude;   % latitude of NH line (decimal degress north) based on LTOP transects
LightParams.SolarConstant	= 1366;       % Solar const. (W m^-2) recent ave. (Froehlich & Lean (1998, Geographical Research Letters 25(23): 4377-4380))

LightParams.par_frac        = 0.43;       % fraction of 40 that is PAR, clear atmos. (Fasham, Ducklow, & McKelvie (1990, J. Mar. Res. 48:591-639), p. 604)
LightParams.surf_trans      = 0.85;       % 1-reflectance (Parsons, Takahachi, & Hargrave (1984, Biological Oceanographic Processes, 3rd ed.), p. 69)
LightParams.cloud_cover     = 0.50;       % fitting daily average and weekly-smoothed light model curve to weekly average of HMSC roof data by eye
% LightParams.cloud_cover     = 0.70;       % Ave. 1990-97, COADS Standard 1-deg. for 125.5W, 45.5N
LightParams.cloud_trans     = 1.0 - (0.7 * LightParams.cloud_cover);  % (Evans and Parslow (1985, Biol. Oceanogr. 3(3):327-347), p. 344)
LightParams.t_grid          = t_grid;

[SurfaceRadiation]          = f_LightIntensity(LightParams);
daily_average_light         = SurfaceRadiation.daily_average_light; % daily integrated solar raditation at ocean surface averaged across 24 hours (W m^-2 h^-1); (vertical vector: num_t X 1)
%                                                 NOTE: the daily average is also what was used by Spitz in her NPZD models
%                                                 NOTE: the daily integrated value avergaed over 24 hours is almost identical to the mean of the current instantaneous light intensity averaged over 24 hours (I checked)
current_light               = SurfaceRadiation.current_light; % surface solar raditation at current time (W/m2)
Kw                          = 0.067;    % Light attenuation_seawater (Newberger et al., 2003); (1/m)
Kp                          = 0.0095;   % Light attenuation_phytoplankton (Newberger et al., 2003); (m2/mmol N)





% *************************************************************************
% STEP 12: pack results for export-----------------------------------------
% step 12a: time dimensions -----------------------------------------------
ECOTRANphysics.datestart                   = datestart;                 % starting date
ECOTRANphysics.dateend                     = dateend;                   % ending date
ECOTRANphysics.t_grid                      = t_grid;
ECOTRANphysics.num_t                       = num_t;

% step 12b: space dimensions ----------------------------------------------
ECOTRANphysics.num_boxes                   = num_boxes;
ECOTRANphysics.BoxLength                   = BoxLength;                 % (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight_inshore           = BoxHeight_inshore;         % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight_offshore          = BoxHeight_offshore;        % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxHeight                   = BoxHeight;                 % I, II, III, IV, V; mean box height; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxWidth                    = BoxWidth;                  % I, II, III, IV, V; (m); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxArea                     = BoxArea;                   % I, II, III, IV, V; (m2); (2D matrix: time X num_boxes)
ECOTRANphysics.BoxVolume                   = BoxVolume;                 % I, II, III, IV, V; (m3); (2D matrix: time X num_boxes)

% step 12c: box addresses -------------------------------------------------
ECOTRANphysics.looky_SubSurfaceBoxes       = looky_SubSurfaceBoxes;
ECOTRANphysics.looky_SurfaceBoxes          = looky_SurfaceBoxes;
ECOTRANphysics.looky_OffshoreSurfaceBox    = looky_OffshoreSurfaceBox;
ECOTRANphysics.looky_OffshoreSubSurfaceBox = looky_OffshoreSubSurfaceBox;
ECOTRANphysics.looky_RiverFluxBox          = looky_RiverFluxBox;        % Optional river alongshore input; (Box 2 in CGoA downwelling model)
ECOTRANphysics.OceanSourceBoxID            = OceanSourceBoxID;          % ocean sourcebox ID; (vertical vector: time X 1)

% step 12d: raw physical driver time-series -------------------------------
ECOTRANphysics.tau                         = tau;                       % Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (horizontal vector)
ECOTRANphysics.tau_doy                     = tau_doy;                   % Alongshore wind stress, monthly mean: (N/m^2) = (kg*m/s2/m2) = (kg/s2/m); (horizontal vector)
ECOTRANphysics.we                          = we;                        % vertical mixing rate, monthly mean: (m/sec)
ECOTRANphysics.we_doy                      = we_doy;                    % vertical mixing rate, monthly mean: (m/sec)
ECOTRANphysics.ue                          = ue;                        % horizontal mixing rate, monthly mean: (m/s); (2d matrix: time X num_AdvecFluxes)
ECOTRANphysics.ue_doy                      = ue_doy;                    % horizontal mixing rate, monthly mean: (m/s); (2d matrix: time X num_AdvecFluxes)

% step 12e: physical driver time-series -----------------------------------
ECOTRANphysics.AdvectionMatrix             = AdvectionMatrix;           % wind-driven advection rate = volume transported per day; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.RiverFluxMatrix             = RiverFluxMatrix;           % river-driven advection rate = volume transported per day; enters into Box II; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.VerticalMixMatrix           = VerticalMixMatrix;         % mixing rate = volume mixed per day; (m3/d); (3D matrix: time X source box X destination box)
ECOTRANphysics.HorizontalMixMatrix         = HorizontalMixMatrix;       % mixing rate = volume mixed per day; (m3/d); (3D matrix: time X source box X destination box)

ECOTRANphysics.HorizontalMix_OffshoreSurface    = HorizontalMix_OffshoreSurface;    % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)
ECOTRANphysics.HorizontalMix_OffshoreSubSurface = HorizontalMix_OffshoreSubSurface; % mixing rate across oceanic boundary = volume mixed per day; (m3/d); (vertical vector: time X 1)

ECOTRANphysics.NetAdvectionMatrix          = NetAdvectionMatrix;        % net advection rate (m3/d); (3D matrix: time X SourceBox X DestinationBox (I II III IV V))
ECOTRANphysics.BoxWashoutTime              = looky_WashoutTime;         % a list of days when one or more boxes would have been >100% washed out if advection cap not applied

% step 12f: misc info -----------------------------------------------------
ECOTRANphysics.SinkLink_surface            = SinkLink_surface;          % define sinking connections from surface to sub-surface boxes; (unitless); (2D matrix: destination boxes X source boxes)
ECOTRANphysics.SinkLink_benthos            = SinkLink_benthos;          % define sinking connections from sub-surface boxes to benthic detritus; (unitless); (2D matrix: destination boxes X source boxes)
ECOTRANphysics.num_AdvecFluxes             = num_AdvecFluxes;
ECOTRANphysics.num_MixFluxes               = num_MixFluxes;
ECOTRANphysics.num_HorizMixFluxes          = num_HorizMixFluxes;

% step 12g: nutrient time-series ------------------------------------------
ECOTRANphysics.dat_NO3                     = dat_NO3;                   % monthly mean NO3 + NO2; (mmole N/m3); (2D matrix: month X box; I, II, III, IV, V)
ECOTRANphysics.NO3_doy                     = NO3_doy;                   % daily NO3 + NO2 interpolated from monthly means; (mmole N/m3); (2D matrix: month X box; I, II, III, IV, V)

% step 12h: light model info ----------------------------------------------
ECOTRANphysics.MLD                         = MLD;                       % time-series of Mixed Layer Depth (for light intensity calculations, NOT advection calcs); (m); (vertical vector: length = time)
ECOTRANphysics.Io                          = daily_average_light;       % time-series of surface PAR light intensity; daily integrated solar raditation at ocean surface averaged across 24 hours; (W m^-2 h^-1) (Brock, 1981, R. Ozretich unpub. data);
ECOTRANphysics.Kw                          = Kw;                        % Light attenuation?seawater
ECOTRANphysics.Kp                          = Kp;                        % Light attenuation?phytoplankton (Newberger et al., 2003); (m2/mmol N)

% step 12i: conversion factors --------------------------------------------
ECOTRANphysics.atomic_mass_C               = atomic_mass_C;             % (g C / mole C)
ECOTRANphysics.atomic_mass_N               = atomic_mass_N;             % (g N / mole N)
ECOTRANphysics.C_to_N_phytoplankton        = C_to_N_phytoplankton;      % Redfield ratio = C:N:P = 106:16:1 ---> C:N = 106:16 = 6.625 mole C/mole N
ECOTRANphysics.C_to_N_zooplankton          = C_to_N_zooplankton;        % general zooplankton C:N (moles C moles N^-1) for mesozooplankton (W. Peterson pers com); C:N=5.16-5.26 [Schneider 1990 (Mar Biol 106:219-225)]; C:N=3.9 [Uye 1982]
ECOTRANphysics.Chla_to_N_diatoms           = Chla_to_N_diatoms;         % (mg Chla mmoles N^-1) (Dickson & Wheeler 1995 L&O 40(3):533-543)
ECOTRANphysics.Chla_to_N_dinoflagellates   = Chla_to_N_dinoflagellates;
ECOTRANphysics.mgWWT_per_mmolesN           = mgWWT_per_mmolesN;         % (mg WWT/mmoles N); for phytoplankton
ECOTRANphysics.WWT_to_C                    = WWT_to_C;                  % (g WWT / g C); (Steele et al. 2007); QQQ recheck this for phytoplankton


% end m-file***************************************************************